"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QMimeType(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qmimetype.html

    **Detailed Description**

    For instance a file named "readme.txt" has the MIME type "text/plain". The
    MIME type can be determined from the file name, or from the file contents,
    or from both. MIME type determination can also be done on buffers of data
    not coming from files.

    Determining the MIME type of a file can be useful to make sure your
    application supports it. It is also useful in file-manager-like applications
    or widgets, in order to display an appropriate **icon**  for the file, or
    even the descriptive **comment**  in detailed views.

    To check if a file has the expected MIME type, you should use **inherits**
    () rather than a simple string comparison based on the **name** (). This is
    because MIME types can inherit from each other: for instance a C source file
    is a specific type of plain text file, so text/x-csrc inherits text/plain.

    **See also** **QMimeDatabase**  and **MIME Type Browser Example** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qmimetype.html#QMimeType

        **QMimeType::QMimeType()**

        Constructs this QMimeType object initialized with default property
        values that indicate an invalid MIME type.
        """
        ...

    @typing.overload
    def __init__(self, other: "QMimeType") -> None:
        """
        https://doc.qt.io/qt-6/qmimetype.html#QMimeType-1

        **QMimeType::QMimeType(const QMimeType & other )**

        Constructs this QMimeType object as a copy of **other**.
        """
        ...

    def __hash__(self) -> int:
        ...

    def filterString(self) -> str:
        """
        https://doc.qt.io/qt-6/qmimetype.html#filterString-prop

        **[read-only] filterString : const QString**

        This property holds a filter string usable for a file dialog

        While this property was introduced in 5.10, the corresponding accessor
        method has always been there.

        **Access functions:**

        QString **filterString** () const
        """
        ...

    def inherits(self, mimeTypeName: str) -> bool:
        """
        https://doc.qt.io/qt-6/qmimetype.html#inherits

        **[invokable] bool QMimeType::inherits(const QString & mimeTypeName )
        const**

        Returns `true` if this mimetype is **mimeTypeName** , or inherits
        **mimeTypeName** (see **parentMimeTypes** ()), or **mimeTypeName** is an
        alias for this mimetype.

        This method has been made invokable from QML since 5.10.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    def preferredSuffix(self) -> str:
        """
        https://doc.qt.io/qt-6/qmimetype.html#preferredSuffix-prop

        **[read-only] preferredSuffix : const QString**

        This property holds the preferred suffix for the MIME type

        No leading dot is included, so for instance this would return "pdf" for
        application/pdf. The return value can be empty, for mime types which do
        not have any suffixes associated.

        While this property was introduced in 5.10, the corresponding accessor
        method has always been there.

        **Access functions:**

        QString **preferredSuffix** () const
        """
        ...

    def suffixes(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qmimetype.html#suffixes-prop

        **[read-only] suffixes : const QStringList**

        This property holds the known suffixes for the MIME type

        No leading dot is included, so for instance this would return "jpg",
        "jpeg" for image/jpeg.

        While this property was introduced in 5.10, the corresponding accessor
        method has always been there.

        **Access functions:**

        QStringList **suffixes** () const
        """
        ...

    def aliases(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qmimetype.html#aliases-prop

        **[read-only] aliases : const QStringList**

        This property holds the list of aliases of this mimetype

        For instance, for text/csv, the returned list would be: text/x-csv,
        text/x-comma-separated-values.

        Note that all **QMimeType**  instances refer to proper mimetypes, never
        to aliases directly.

        The order of the aliases in the list is undefined.

        While this property was introduced in 5.10, the corresponding accessor
        method has always been there.

        **Access functions:**

        QStringList **aliases** () const
        """
        ...

    def allAncestors(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qmimetype.html#allAncestors-prop

        **[read-only] allAncestors : const QStringList**

        This property holds the names of direct and indirect parent MIME types

        Return all the parent mimetypes of this mimetype, direct and indirect.
        This includes the parent(s) of its parent(s), etc.

        For instance, for image/svg+xml the list would be: application/xml,
        text/plain, application/octet-stream.

        Note that application/octet-stream is the ultimate parent for all types
        of files (but not directories).

        While this property was introduced in 5.10, the corresponding accessor
        method has always been there.

        **Access functions:**

        QStringList **allAncestors** () const
        """
        ...

    def parentMimeTypes(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qmimetype.html#parentMimeTypes-prop

        **[read-only] parentMimeTypes : const QStringList**

        This property holds the names of parent MIME types

        A type is a subclass of another type if any instance of the first type
        is also an instance of the second. For example, all image/svg+xml files
        are also text/xml, text/plain and application/octet-stream files.
        Subclassing is about the format, rather than the category of the data
        (for example, there is no 'generic spreadsheet' class that all
        spreadsheets inherit from). Conversely, the parent mimetype of
        image/svg+xml is text/xml.

        A mimetype can have multiple parents. For instance application/x-perl
        has two parents: application/x-executable and text/plain. This makes it
        possible to both execute perl scripts, and to open them in text editors.

        While this property was introduced in 5.10, the corresponding accessor
        method has always been there.

        **Access functions:**

        QStringList **parentMimeTypes** () const
        """
        ...

    def globPatterns(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qmimetype.html#globPatterns-prop

        **[read-only] globPatterns : const QStringList**

        This property holds the list of glob matching patterns

        While this property was introduced in 5.10, the corresponding accessor
        method has always been there.

        **Access functions:**

        QStringList **globPatterns** () const
        """
        ...

    def iconName(self) -> str:
        """
        https://doc.qt.io/qt-6/qmimetype.html#iconName-prop

        **[read-only] iconName : const QString**

        This property holds the file name of an icon image that represents the
        MIME type

        The icon name can be given to **QIcon::fromTheme** () in order to load
        the icon.

        While this property was introduced in 5.10, the corresponding accessor
        method has always been there.

        **Access functions:**

        QString **iconName** () const
        """
        ...

    def genericIconName(self) -> str:
        """
        https://doc.qt.io/qt-6/qmimetype.html#genericIconName-prop

        **[read-only] genericIconName : const QString**

        This property holds the file name of a generic icon that represents the
        MIME type

        This should be used if the icon returned by **iconName** () cannot be
        found on the system. It is used for categories of similar types (like
        spreadsheets or archives) that can use a common icon. The
        freedesktop.org Icon Naming Specification lists a set of such icon
        names.

        The icon name can be given to **QIcon::fromTheme** () in order to load
        the icon.

        While this property was introduced in 5.10, the corresponding accessor
        method has always been there.

        **Access functions:**

        QString **genericIconName** () const
        """
        ...

    def comment(self) -> str:
        """
        https://doc.qt.io/qt-6/qmimetype.html#comment-prop

        **[read-only] comment : const QString**

        This property holds the description of the MIME type to be displayed on
        user interfaces

        The default language (QLocale().**name** ()) is used to select the
        appropriate translation.

        While this property was introduced in 5.10, the corresponding accessor
        method has always been there.

        **Access functions:**

        QString **comment** () const
        """
        ...

    def name(self) -> str:
        """
        https://doc.qt.io/qt-6/qmimetype.html#name-prop

        **[read-only] name : const QString**

        This property holds the name of the MIME type

        While this property was introduced in 5.10, the corresponding accessor
        method has always been there.

        **Access functions:**

        QString **name** () const
        """
        ...

    def isDefault(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmimetype.html#isDefault-prop

        **[read-only] isDefault : const bool**

        `true` if this MIME type is the default MIME type which applies to all
        files: application/octet-stream.

        While this property was introduced in 5.10, the corresponding accessor
        method has always been there.

        **Access functions:**

        bool **isDefault** () const
        """
        ...

    def isValid(self) -> bool:
        ...

    def swap(self, other: "QMimeType") -> None:
        """
        https://doc.qt.io/qt-6/qmimetype.html#swap

        **void QMimeType::swap(QMimeType & other )**

        Swaps **QMimeType**  **other** with this **QMimeType**  object.

        This operation is very fast and never fails.

        The swap() method helps with the implementation of assignment operators
        in an exception-safe way. For more information consult **More C++ Idioms
        - Copy-and-swap** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtCore


class QDragLeaveEvent(QtCore.QEvent):
    """
    https://doc.qt.io/qt-6/qdragleaveevent.html

    **Detailed Description**

    This event is always preceded by a **QDragEnterEvent**  and a series of
    **QDragMoveEvent** s. It is not sent if a **QDropEvent**  is sent instead.

    **See also** **QDragEnterEvent** , **QDragMoveEvent** , and **QDropEvent** .
    """

    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qdragleaveevent.html#QDragLeaveEvent-2

        **QDragLeaveEvent::QDragLeaveEvent()**

        Constructs a QDragLeaveEvent.

        **Warning:** Do not create a QDragLeaveEvent yourself since these
        objects rely on Qt's internal state.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtCore import *


class QSortFilterProxyModel(QAbstractProxyModel):
    """
    https://doc.qt.io/qt-6/qsortfilterproxymodel.html

    **Detailed Description**

    QSortFilterProxyModel can be used for sorting items, filtering out items, or
    both. The model transforms the structure of a source model by mapping the
    model indexes it supplies to new indexes, corresponding to different
    locations, for views to use. This approach allows a given source model to be
    restructured as far as views are concerned without requiring any
    transformations on the underlying data, and without duplicating the data in
    memory.

    Let's assume that we want to sort and filter the items provided by a custom
    model. The code to set up the model and the view, **without** sorting and
    filtering, would look like this:

    **QTreeView**  *treeView = new **QTreeView** ;
                MyItemModel
    *model = new MyItemModel(this);

                treeView->setModel(model);

    To add sorting and filtering support to `MyItemModel`, we need to create a
    QSortFilterProxyModel, call **setSourceModel** () with the `MyItemModel` as
    argument, and install the QSortFilterProxyModel on the view:

    **QTreeView**  *treeView = new **QTreeView** ;
                MyItemModel
    *sourceModel = new MyItemModel(this);
                **QSortFilterProxyModel**
    *proxyModel = new **QSortFilterProxyModel** (this);
    proxyModel->setSourceModel(sourceModel);
    treeView->setModel(proxyModel);

    At this point, neither sorting nor filtering is enabled; the original data
    is displayed in the view. Any changes made through the QSortFilterProxyModel
    are applied to the original model.

    The QSortFilterProxyModel acts as a wrapper for the original model. If you
    need to convert source **QModelIndex** es to sorted/filtered model indexes
    or vice versa, use **mapToSource** (), **mapFromSource** (),
    **mapSelectionToSource** (), and **mapSelectionFromSource** ().

    **Note:** By default, the model dynamically re-sorts and re-filters data
    whenever the original model changes. This behavior can be changed by setting
    the **dynamicSortFilter**  property.

    The **Basic Sort/Filter Model**  and **Custom Sort/Filter Model**  examples
    illustrate how to use QSortFilterProxyModel to perform basic sorting and
    filtering and how to subclass it to implement custom behavior.

    **Sorting**

    **QTableView**  and **QTreeView**  have a **sortingEnabled**  property that
    controls whether the user can sort the view by clicking the view's
    horizontal header. For example:

    treeView->setSortingEnabled(true);

    When this feature is on (the default is off), clicking on a header section
    sorts the items according to that column. By clicking repeatedly, the user
    can alternate between ascending and descending order.

    ![A sorted QTreeView](images/qsortfilterproxymodel-sorting.png)

    Behind the scene, the view calls the **sort** () virtual function on the
    model to reorder the data in the model. To make your data sortable, you can
    either implement **sort** () in your model, or use a QSortFilterProxyModel
    to wrap your model -- QSortFilterProxyModel provides a generic **sort** ()
    reimplementation that operates on the **sortRole** () (**Qt::DisplayRole**
    by default) of the items and that understands several data types, including
    `int`, **QString** , and **QDateTime** . For hierarchical models, sorting is
    applied recursively to all child items. String comparisons are case
    sensitive by default; this can be changed by setting the
    **sortCaseSensitivity**  property.

    Custom sorting behavior is achieved by subclassing QSortFilterProxyModel and
    reimplementing **lessThan** (), which is used to compare items. For example:

    bool MySortFilterProxyModel::lessThan(const **QModelIndex**  &left,
    const **QModelIndex**  &right) const
        {
            **QVariant**  leftData =
    sourceModel()->data(left);
            **QVariant**  rightData =
    sourceModel()->data(right);

            if (leftData.userType() ==
    **QMetaType** ::**QDateTime** ) {
                return leftData.toDateTime() <
    rightData.toDateTime();
            } else {
                static const
    **QRegularExpression**  emailPattern("[\\\\w\\\\.]*@[\\\\w\\\\.]*");
    **QString**  leftString = leftData.toString();
                if (left.column()
    == 1) {
                    const **QRegularExpressionMatch**  match =
    emailPattern.match(leftString);
                    if (match.hasMatch())
    leftString = match.captured(0);
                }
                **QString**
    rightString = rightData.toString();
                if (right.column() == 1) {
    const **QRegularExpressionMatch**  match = emailPattern.match(rightString);
    if (match.hasMatch())
                        rightString = match.captured(0);
    }

                return **QString** ::localeAwareCompare(leftString,
    rightString) < 0;
            }
        }

    (This code snippet comes from the **Custom Sort/Filter Model**  example.)

    An alternative approach to sorting is to disable sorting on the view and to
    impose a certain order to the user. This is done by explicitly calling
    **sort** () with the desired column and order as arguments on the
    QSortFilterProxyModel (or on the original model if it implements **sort**
    ()). For example:

    proxyModel->sort(2, Qt::AscendingOrder);

    QSortFilterProxyModel can be sorted by column -1, in which case it returns
    to the sort order of the underlying source model.

    **Filtering**

    In addition to sorting, QSortFilterProxyModel can be used to hide items that
    do not match a certain filter. The filter is specified using a
    **QRegularExpression**  object and is applied to the **filterRole** ()
    (**Qt::DisplayRole**  by default) of each item, for a given column. The
    **QRegularExpression**  object can be used to match a regular expression, a
    wildcard pattern, or a fixed string. For example:

    proxyModel->setFilterRegularExpression(**QRegularExpression** ("\\.png",
    **QRegularExpression** ::CaseInsensitiveOption));
    proxyModel->setFilterKeyColumn(1);

    For hierarchical models, the filter is applied recursively to all children.
    If a parent item doesn't match the filter, none of its children will be
    shown.

    A common use case is to let the user specify the filter regular expression,
    wildcard pattern, or fixed string in a **QLineEdit**  and to connect the
    **textChanged** () signal to **setFilterRegularExpression** (),
    **setFilterWildcard** (), or **setFilterFixedString** () to reapply the
    filter.

    Custom filtering behavior can be achieved by reimplementing the
    **filterAcceptsRow** () and **filterAcceptsColumn** () functions. For
    example (from the **Custom Sort/Filter Model**  example), the following
    implementation ignores the **filterKeyColumn**  property and performs
    filtering on columns 0, 1, and 2:

    bool MySortFilterProxyModel::filterAcceptsRow(int sourceRow,
    const **QModelIndex**  &sourceParent) const
        {
            **QModelIndex**
    index0 = sourceModel()->index(sourceRow, 0, sourceParent);
    **QModelIndex**  index1 = sourceModel()->index(sourceRow, 1, sourceParent);
    **QModelIndex**  index2 = sourceModel()->index(sourceRow, 2, sourceParent);
    return
    (sourceModel()->data(index0).toString().contains(filterRegularExpression())
    ||
    sourceModel()->data(index1).toString().contains(filterRegularExpression()))
    && dateInRange(sourceModel()->data(index2).toDate());
        }

    (This code snippet comes from the **Custom Sort/Filter Model**  example.)

    If you are working with large amounts of filtering and have to invoke
    **invalidateFilter** () repeatedly, using **beginResetModel** () /
    **endResetModel** () may be more efficient, depending on the implementation
    of your model. However, **beginResetModel** () / **endResetModel** ()
    returns the proxy model to its original state, losing selection information,
    and will cause the proxy model to be repopulated.

    **Subclassing**

    Since **QAbstractProxyModel**  and its subclasses are derived from
    **QAbstractItemModel** , much of the same advice about subclassing normal
    models also applies to proxy models. In addition, it is worth noting that
    many of the default implementations of functions in this class are written
    so that they call the equivalent functions in the relevant source model.
    This simple proxying mechanism may need to be overridden for source models
    with more complex behavior; for example, if the source model provides a
    custom **hasChildren** () implementation, you should also provide one in the
    proxy model.

    **Note:** Some general guidelines for subclassing models are available in
    the **Model Subclassing Reference** .

    **See also** **QAbstractProxyModel** , **QAbstractItemModel** , **Model/View
    Programming** , **Basic Sort/Filter Model Example** , **Custom Sort/Filter
    Model Example** , and **QIdentityProxyModel** .
    """

    def __init__(self, parent: typing.Optional[QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#QSortFilterProxyModel

        **QSortFilterProxyModel::QSortFilterProxyModel(QObject * parent =
        nullptr)**

        Constructs a sorting filter model with the given **parent**.
        """
        ...

    def invalidateColumnsFilter(self) -> None:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#invalidateColumnsFilte
        r

        **[protected, since 6.0] void
        QSortFilterProxyModel::invalidateColumnsFilter()**

        Invalidates the current filtering for the columns.

        This function should be called if you are implementing custom filtering
        (by **filterAcceptsColumn** ()), and your filter parameters have
        changed. This differs from **invalidateFilter** () in that it will not
        invoke **filterAcceptsRow** (), but only **filterAcceptsColumn** (). You
        can use this instead of **invalidateFilter** () if you want to hide or
        show a column where the rows don't change.

        This function was introduced in Qt 6.0.

        **See also** **invalidate** (), **invalidateFilter** (), and
        **invalidateRowsFilter** ().
        """
        ...

    def invalidateRowsFilter(self) -> None:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#invalidateRowsFilter

        **[protected, since 6.0] void
        QSortFilterProxyModel::invalidateRowsFilter()**

        Invalidates the current filtering for the rows.

        This function should be called if you are implementing custom filtering
        (by **filterAcceptsRow** ()), and your filter parameters have changed.
        This differs from **invalidateFilter** () in that it will not invoke
        **filterAcceptsColumn** (), but only **filterAcceptsRow** (). You can
        use this instead of **invalidateFilter** () if you want to hide or show
        a row where the columns don't change.

        This function was introduced in Qt 6.0.

        **See also** **invalidate** (), **invalidateFilter** (), and
        **invalidateColumnsFilter** ().
        """
        ...

    def setAutoAcceptChildRows(self, accept: bool) -> None:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#autoAcceptChildRows-
        prop

        **[bindable, since 6.0] autoAcceptChildRows : bool**

        **Note:** This property supports **QProperty**  bindings.

        if true the proxy model will not filter out children of accepted rows,
        even if they themselves would be filtered out otherwise.

        The default value is false.

        This property was introduced in Qt 6.0.

        **See also** **recursiveFilteringEnabled**  and **filterAcceptsRow** ().
        """
        ...

    def autoAcceptChildRows(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#autoAcceptChildRows-
        prop

        **[bindable, since 6.0] autoAcceptChildRows : bool**

        **Note:** This property supports **QProperty**  bindings.

        if true the proxy model will not filter out children of accepted rows,
        even if they themselves would be filtered out otherwise.

        The default value is false.

        This property was introduced in Qt 6.0.

        **See also** **recursiveFilteringEnabled**  and **filterAcceptsRow** ().
        """
        ...

    def dynamicSortFilterChanged(self, dynamicSortFilter: bool) -> None:
        ...

    def invalidateFilter(self) -> None:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#invalidateFilter

        **[protected] void QSortFilterProxyModel::invalidateFilter()**

        Invalidates the current filtering.

        This function should be called if you are implementing custom filtering
        (e.g. **filterAcceptsRow** ()), and your filter parameters have changed.

        **See also** **invalidate** (), **invalidateColumnsFilter** (), and
        **invalidateRowsFilter** ().
        """
        ...

    def setRecursiveFilteringEnabled(self, recursive: bool) -> None:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#recursiveFilteringEnab
        led-prop

        **[bindable, since 5.10] recursiveFilteringEnabled : bool**

        **Note:** This property supports **QProperty**  bindings.

        This property holds whether the filter to be applied recursively on
        children, and for any matching child, its parents will be visible as
        well.

        The default value is false.

        This property was introduced in Qt 5.10.

        **See also** **autoAcceptChildRows**  and **filterAcceptsRow** ().
        """
        ...

    def isRecursiveFilteringEnabled(self) -> bool:
        ...

    def sibling(self, row: int, column: int, idx: QModelIndex) -> QModelIndex:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#sibling

        **[override virtual] QModelIndex QSortFilterProxyModel::sibling(int row
        , int column , const QModelIndex & idx ) const**

        Reimplements: **QAbstractProxyModel::sibling(int row, int column, const
        QModelIndex &idx) const** .
        """
        ...

    def setSortLocaleAware(self, on: bool) -> None:
        ...

    def isSortLocaleAware(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#isSortLocaleAware-prop

        **[bindable] isSortLocaleAware : bool**

        **Note:** This property supports **QProperty**  bindings.

        This property holds the local aware setting used for comparing strings
        when sorting

        By default, sorting is not local aware.

        **See also** **sortCaseSensitivity**  and **lessThan** ().
        """
        ...

    def supportedDropActions(self) -> Qt.DropAction:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#supportedDropActions

        **[override virtual] Qt::DropActions
        QSortFilterProxyModel::supportedDropActions() const**

        Reimplements: **QAbstractProxyModel::supportedDropActions() const** .
        """
        ...

    def mimeTypes(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#mimeTypes

        **[override virtual] QStringList QSortFilterProxyModel::mimeTypes()
        const**

        Reimplements: **QAbstractProxyModel::mimeTypes() const** .
        """
        ...

    def setFilterRole(self, role: int) -> None:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#filterRole-prop

        **[bindable] filterRole : int**

        **Note:** This property supports **QProperty**  bindings.

        This property holds the item role that is used to query the source
        model's data when filtering items.

        The default value is **Qt::DisplayRole** .

        **See also** **filterAcceptsRow** ().
        """
        ...

    def filterRole(self) -> int:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#filterRole-prop

        **[bindable] filterRole : int**

        **Note:** This property supports **QProperty**  bindings.

        This property holds the item role that is used to query the source
        model's data when filtering items.

        The default value is **Qt::DisplayRole** .

        **See also** **filterAcceptsRow** ().
        """
        ...

    def sortOrder(self) -> Qt.SortOrder:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#sortOrder

        **Qt::SortOrder QSortFilterProxyModel::sortOrder() const**

        the order currently used for sorting

        This returns the most recently used sort order.
        """
        ...

    def sortColumn(self) -> int:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#sortColumn

        **int QSortFilterProxyModel::sortColumn() const**

        the column currently used for sorting

        This returns the most recently used sort column.
        """
        ...

    def setSortRole(self, role: int) -> None:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#sortRole-prop

        **[bindable] sortRole : int**

        **Note:** This property supports **QProperty**  bindings.

        This property holds the item role that is used to query the source
        model's data when sorting items.

        The default value is **Qt::DisplayRole** .

        **See also** **lessThan** ().

        **Member Function Documentation**
        """
        ...

    def sortRole(self) -> int:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#sortRole-prop

        **[bindable] sortRole : int**

        **Note:** This property supports **QProperty**  bindings.

        This property holds the item role that is used to query the source
        model's data when sorting items.

        The default value is **Qt::DisplayRole** .

        **See also** **lessThan** ().

        **Member Function Documentation**
        """
        ...

    def setDynamicSortFilter(self, enable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#dynamicSortFilter-prop

        **[bindable] dynamicSortFilter : bool**

        **Note:** This property supports **QProperty**  bindings.

        This property holds whether the proxy model is dynamically sorted and
        filtered whenever the contents of the source model change

        Note that you should not update the source model through the proxy model
        when dynamicSortFilter is true. For instance, if you set the proxy model
        on a **QComboBox** , then using functions that update the model, e.g.,
        **addItem** (), will not work as expected. An alternative is to set
        dynamicSortFilter to false and call **sort** () after adding items to
        the **QComboBox** .

        The default value is true.
        """
        ...

    def dynamicSortFilter(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#dynamicSortFilter-prop

        **[bindable] dynamicSortFilter : bool**

        **Note:** This property supports **QProperty**  bindings.

        This property holds whether the proxy model is dynamically sorted and
        filtered whenever the contents of the source model change

        Note that you should not update the source model through the proxy model
        when dynamicSortFilter is true. For instance, if you set the proxy model
        on a **QComboBox** , then using functions that update the model, e.g.,
        **addItem** (), will not work as expected. An alternative is to set
        dynamicSortFilter to false and call **sort** () after adding items to
        the **QComboBox** .

        The default value is true.
        """
        ...

    def setSortCaseSensitivity(self, cs: Qt.CaseSensitivity) -> None:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#sortCaseSensitivity-
        prop

        **[bindable] sortCaseSensitivity : Qt::CaseSensitivity**

        **Note:** This property supports **QProperty**  bindings.

        This property holds the case sensitivity setting used for comparing
        strings when sorting

        By default, sorting is case sensitive.

        **See also** **filterCaseSensitivity**  and **lessThan** ().
        """
        ...

    def sortCaseSensitivity(self) -> Qt.CaseSensitivity:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#sortCaseSensitivity-
        prop

        **[bindable] sortCaseSensitivity : Qt::CaseSensitivity**

        **Note:** This property supports **QProperty**  bindings.

        This property holds the case sensitivity setting used for comparing
        strings when sorting

        By default, sorting is case sensitive.

        **See also** **filterCaseSensitivity**  and **lessThan** ().
        """
        ...

    def sort(self, column: int, order: Qt.SortOrder = ...) -> None:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#sort

        **[override virtual] void QSortFilterProxyModel::sort(int column ,
        Qt::SortOrder order = Qt::AscendingOrder)**

        Reimplements: **QAbstractProxyModel::sort** (int column, Qt::SortOrder
        order).
        """
        ...

    def match(
        self,
        start: QModelIndex,
        role: int,
        value: typing.Any,
        hits: int = ...,
        flags: Qt.MatchFlag = ...,
    ) -> typing.List[QModelIndex]:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#match

        **[override virtual] QModelIndexList QSortFilterProxyModel::match(const
        QModelIndex & start , int role , const QVariant & value , int hits = 1,
        Qt::MatchFlags flags =
        Qt::MatchFlags(Qt::MatchStartsWith|Qt::MatchWrap)) const**

        Reimplements: **QAbstractItemModel::match(const QModelIndex &start, int
        role, const QVariant &value, int hits, Qt::MatchFlags flags) const** .
        """
        ...

    def span(self, index: QModelIndex) -> QSize:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#span

        **[override virtual] QSize QSortFilterProxyModel::span(const QModelIndex
        & index ) const**

        Reimplements: **QAbstractProxyModel::span(const QModelIndex &index)
        const** .
        """
        ...

    def buddy(self, index: QModelIndex) -> QModelIndex:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#buddy

        **[override virtual] QModelIndex QSortFilterProxyModel::buddy(const
        QModelIndex & index ) const**

        Reimplements: **QAbstractProxyModel::buddy(const QModelIndex &index)
        const** .
        """
        ...

    def flags(self, index: QModelIndex) -> Qt.ItemFlag:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#flags

        **[override virtual] Qt::ItemFlags QSortFilterProxyModel::flags(const
        QModelIndex & index ) const**

        Reimplements: **QAbstractProxyModel::flags(const QModelIndex &index)
        const** .
        """
        ...

    def canFetchMore(self, parent: QModelIndex) -> bool:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#canFetchMore

        **[override virtual] bool QSortFilterProxyModel::canFetchMore(const
        QModelIndex & parent ) const**

        Reimplements: **QAbstractProxyModel::canFetchMore(const QModelIndex
        &parent) const** .
        """
        ...

    def fetchMore(self, parent: QModelIndex) -> None:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#fetchMore

        **[override virtual] void QSortFilterProxyModel::fetchMore(const
        QModelIndex & parent )**

        Reimplements: **QAbstractProxyModel::fetchMore** (const QModelIndex
        &parent).
        """
        ...

    def removeColumns(self, column: int, count: int, parent: QModelIndex = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#removeColumns

        **[override virtual] bool QSortFilterProxyModel::removeColumns(int
        column , int count , const QModelIndex & parent = QModelIndex())**

        Reimplements: **QAbstractItemModel::removeColumns** (int column, int
        count, const QModelIndex &parent).
        """
        ...

    def removeRows(self, row: int, count: int, parent: QModelIndex = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#removeRows

        **[override virtual] bool QSortFilterProxyModel::removeRows(int row ,
        int count , const QModelIndex & parent = QModelIndex())**

        Reimplements: **QAbstractItemModel::removeRows** (int row, int count,
        const QModelIndex &parent).
        """
        ...

    def insertColumns(self, column: int, count: int, parent: QModelIndex = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#insertColumns

        **[override virtual] bool QSortFilterProxyModel::insertColumns(int
        column , int count , const QModelIndex & parent = QModelIndex())**

        Reimplements: **QAbstractItemModel::insertColumns** (int column, int
        count, const QModelIndex &parent).
        """
        ...

    def insertRows(self, row: int, count: int, parent: QModelIndex = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#insertRows

        **[override virtual] bool QSortFilterProxyModel::insertRows(int row ,
        int count , const QModelIndex & parent = QModelIndex())**

        Reimplements: **QAbstractItemModel::insertRows** (int row, int count,
        const QModelIndex &parent).
        """
        ...

    def dropMimeData(
        self,
        data: QMimeData,
        action: Qt.DropAction,
        row: int,
        column: int,
        parent: QModelIndex,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#dropMimeData

        **[override virtual] bool QSortFilterProxyModel::dropMimeData(const
        QMimeData * data , Qt::DropAction action , int row , int column , const
        QModelIndex & parent )**

        Reimplements: **QAbstractProxyModel::dropMimeData** (const QMimeData
        *data, Qt::DropAction action, int row, int column, const QModelIndex
        &parent).
        """
        ...

    def mimeData(self, indexes: typing.Iterable[QModelIndex]) -> QMimeData:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#mimeData

        **[override virtual] QMimeData *QSortFilterProxyModel::mimeData(const
        QModelIndexList & indexes ) const**

        Reimplements: **QAbstractProxyModel::mimeData(const QModelIndexList
        &indexes) const** .
        """
        ...

    def setHeaderData(
        self,
        section: int,
        orientation: Qt.Orientation,
        value: typing.Any,
        role: int = ...,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#setHeaderData

        **[override virtual] bool QSortFilterProxyModel::setHeaderData(int
        section , Qt::Orientation orientation , const QVariant & value , int
        role = Qt::EditRole)**

        Reimplements: **QAbstractProxyModel::setHeaderData** (int section,
        Qt::Orientation orientation, const QVariant &value, int role).

        **See also** **headerData** ().
        """
        ...

    def headerData(
        self, section: int, orientation: Qt.Orientation, role: int = ...
    ) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#headerData

        **[override virtual] QVariant QSortFilterProxyModel::headerData(int
        section , Qt::Orientation orientation , int role = Qt::DisplayRole)
        const**

        Reimplements: **QAbstractProxyModel::headerData(int section,
        Qt::Orientation orientation, int role) const** .

        **See also** **setHeaderData** ().
        """
        ...

    def setData(self, index: QModelIndex, value: typing.Any, role: int = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#setData

        **[override virtual] bool QSortFilterProxyModel::setData(const
        QModelIndex & index , const QVariant & value , int role =
        Qt::EditRole)**

        Reimplements: **QAbstractProxyModel::setData** (const QModelIndex
        &index, const QVariant &value, int role).

        **See also** **data** ().
        """
        ...

    def data(self, index: QModelIndex, role: int = ...) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#data

        **[override virtual] QVariant QSortFilterProxyModel::data(const
        QModelIndex & index , int role = Qt::DisplayRole) const**

        Reimplements: **QAbstractProxyModel::data(const QModelIndex &proxyIndex,
        int role) const** .

        **See also** **setData** ().
        """
        ...

    def hasChildren(self, parent: QModelIndex = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#hasChildren

        **[override virtual] bool QSortFilterProxyModel::hasChildren(const
        QModelIndex & parent = QModelIndex()) const**

        Reimplements: **QAbstractProxyModel::hasChildren(const QModelIndex
        &parent) const** .
        """
        ...

    def columnCount(self, parent: QModelIndex = ...) -> int:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#columnCount

        **[override virtual] int QSortFilterProxyModel::columnCount(const
        QModelIndex & parent = QModelIndex()) const**

        Reimplements: **QAbstractItemModel::columnCount(const QModelIndex
        &parent) const** .
        """
        ...

    def rowCount(self, parent: QModelIndex = ...) -> int:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#rowCount

        **[override virtual] int QSortFilterProxyModel::rowCount(const
        QModelIndex & parent = QModelIndex()) const**

        Reimplements: **QAbstractItemModel::rowCount(const QModelIndex &parent)
        const** .
        """
        ...

    @typing.overload
    def parent(self, child: QModelIndex) -> QModelIndex:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#parent

        **[override virtual] QModelIndex QSortFilterProxyModel::parent(const
        QModelIndex & child ) const**

        Reimplements: **QAbstractItemModel::parent(const QModelIndex &index)
        const** .
        """
        ...

    @typing.overload
    def parent(self) -> QObject:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#parent

        **[override virtual] QModelIndex QSortFilterProxyModel::parent(const
        QModelIndex & child ) const**

        Reimplements: **QAbstractItemModel::parent(const QModelIndex &index)
        const** .
        """
        ...

    def index(self, row: int, column: int, parent: QModelIndex = ...) -> QModelIndex:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#index

        **[override virtual] QModelIndex QSortFilterProxyModel::index(int row ,
        int column , const QModelIndex & parent = QModelIndex()) const**

        Reimplements: **QAbstractItemModel::index(int row, int column, const
        QModelIndex &parent) const** .
        """
        ...

    def lessThan(self, left: QModelIndex, right: QModelIndex) -> bool:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#lessThan

        **[virtual protected] bool QSortFilterProxyModel::lessThan(const
        QModelIndex & source_left , const QModelIndex & source_right ) const**

        Returns `true` if the value of the item referred to by the given index
        **source_left** is less than the value of the item referred to by the
        given index **source_right** , otherwise returns `false`.

        This function is used as the < operator when sorting, and handles the
        following **QVariant**  types:

        * **QMetaType::Int**
          * **QMetaType::UInt**
          *
        **QMetaType::LongLong**
          * **QMetaType::ULongLong**
          *
        **QMetaType::Float**
          * **QMetaType::Double**
          *
        **QMetaType::QChar**
          * **QMetaType::QDate**
          * **QMetaType::QTime**
        * **QMetaType::QDateTime**
          * **QMetaType::QString**

        Any other type will be converted to a **QString**  using
        **QVariant::toString** ().

        Comparison of **QString** s is case sensitive by default; this can be
        changed using the **sortCaseSensitivity**  property.

        By default, the **Qt::DisplayRole**  associated with the **QModelIndex**
        es is used for comparisons. This can be changed by setting the
        **sortRole**  property.

        **Note:** The indices passed in correspond to the source model.

        **See also** **sortRole** , **sortCaseSensitivity** , and
        **dynamicSortFilter** .
        """
        ...

    def filterAcceptsColumn(
        self, source_column: int, source_parent: QModelIndex
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#filterAcceptsColumn

        **[virtual protected] bool
        QSortFilterProxyModel::filterAcceptsColumn(int source_column , const
        QModelIndex & source_parent ) const**

        Returns `true` if the item in the column indicated by the given
        **source_column** and **source_parent** should be included in the model;
        otherwise returns `false`.

        **Note:** The default implementation always returns `true`. You must
        reimplement this method to get the described behavior.

        **See also** **filterAcceptsRow** (), **setFilterFixedString** (),
        **setFilterRegularExpression** (), and **setFilterWildcard** ().
        """
        ...

    def filterAcceptsRow(self, source_row: int, source_parent: QModelIndex) -> bool:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#filterAcceptsRow

        **[virtual protected] bool QSortFilterProxyModel::filterAcceptsRow(int
        source_row , const QModelIndex & source_parent ) const**

        Returns `true` if the item in the row indicated by the given
        **source_row** and **source_parent** should be included in the model;
        otherwise returns false.

        The default implementation returns `true` if the value held by the
        relevant item matches the filter string, wildcard string or regular
        expression.

        **Note:** By default, the **Qt::DisplayRole**  is used to determine if
        the row should be accepted or not. This can be changed by setting the
        **filterRole**  property.

        **See also** **filterAcceptsColumn** (), **setFilterFixedString** (),
        **setFilterRegularExpression** (), and **setFilterWildcard** ().
        """
        ...

    def setFilterWildcard(self, pattern: str) -> None:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#setFilterWildcard

        **[slot] void QSortFilterProxyModel::setFilterWildcard(const QString &
        pattern )**

        Sets the wildcard expression used to filter the contents of the source
        model to the given **pattern**.

        This method will reset the regular expression options but respect case
        sensitivity.

        **Note:** Calling this method updates the regular expression, thereby
        breaking the binding for **filterRegularExpression** . However it has no
        effect on the **filterCaseSensitivity**  bindings.

        **See also** **setFilterCaseSensitivity** (),
        **setFilterRegularExpression** (), **setFilterFixedString** (), and
        **filterRegularExpression** ().
        """
        ...

    @typing.overload
    def setFilterRegularExpression(self, regularExpression: QRegularExpression) -> None:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#setFilterRegularExpres
        sion

        **[slot, since 5.12] void
        QSortFilterProxyModel::setFilterRegularExpression(const QString &
        pattern )**

        Sets the regular expression used to filter the contents of the source
        model to **pattern**.

        This method should be preferred for new code as it will use
        **QRegularExpression**  internally.

        This method will reset the regular expression options but respect case
        sensitivity.

        **Note:** Calling this method updates the regular expression, thereby
        breaking the binding for **filterRegularExpression** . However it has no
        effect on the **filterCaseSensitivity**  bindings.

        **Note:** Setter function for property **filterRegularExpression** .

        This function was introduced in Qt 5.12.

        **See also** **setFilterCaseSensitivity** (), **setFilterWildcard** (),
        **setFilterFixedString** (), and **filterRegularExpression** ().
        """
        ...

    @typing.overload
    def setFilterRegularExpression(self, pattern: str) -> None:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#filterRegularExpressio
        n-prop

        **[bindable, since 5.12] filterRegularExpression : QRegularExpression**

        **Note:** This property supports **QProperty**  bindings.

        This property holds the **QRegularExpression**  used to filter the
        contents of the source model

        Setting this property through the **QRegularExpression**  overload
        overwrites the current **filterCaseSensitivity** . By default, the
        **QRegularExpression**  is an empty string matching all contents.

        If no **QRegularExpression**  or an empty string is set, everything in
        the source model will be accepted.

        **Note:** Setting this property propagates the case sensitivity of the
        new regular expression to the **filterCaseSensitivity**  property, and
        so breaks its binding. Likewise explicitly setting
        **filterCaseSensitivity**  changes the case sensitivity of the current
        regular expression, thereby breaking its binding.

        This property was introduced in Qt 5.12.

        **See also** **filterCaseSensitivity** , **setFilterWildcard** (), and
        **setFilterFixedString** ().
        """
        ...

    def setFilterFixedString(self, pattern: str) -> None:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#setFilterFixedString

        **[slot] void QSortFilterProxyModel::setFilterFixedString(const QString
        & pattern )**

        Sets the fixed string used to filter the contents of the source model to
        the given **pattern**.

        This method will reset the regular expression options but respect case
        sensitivity.

        **Note:** Calling this method updates the regular expression, thereby
        breaking the binding for **filterRegularExpression** . However it has no
        effect on the **filterCaseSensitivity**  bindings.

        **See also** **setFilterCaseSensitivity** (),
        **setFilterRegularExpression** (), **setFilterWildcard** (), and
        **filterRegularExpression** ().
        """
        ...

    def invalidate(self) -> None:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#invalidate

        **[slot] void QSortFilterProxyModel::invalidate()**

        Invalidates the current sorting and filtering.

        **See also** **invalidateFilter** ().
        """
        ...

    def setFilterCaseSensitivity(self, cs: Qt.CaseSensitivity) -> None:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#filterCaseSensitivity-
        prop

        **[bindable] filterCaseSensitivity : Qt::CaseSensitivity**

        **Note:** This property supports **QProperty**  bindings.

        This property holds the case sensitivity of the **QRegularExpression**
        pattern used to filter the contents of the source model.

        By default, the filter is case sensitive.

        **Note:** Setting this property propagates the new case sensitivity to
        the **filterRegularExpression**  property, and so breaks its binding.
        Likewise explicitly setting **filterRegularExpression**  changes the
        current case sensitivity, thereby breaking its binding.

        **See also** **filterRegularExpression**  and **sortCaseSensitivity** .
        """
        ...

    def filterCaseSensitivity(self) -> Qt.CaseSensitivity:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#filterCaseSensitivity-
        prop

        **[bindable] filterCaseSensitivity : Qt::CaseSensitivity**

        **Note:** This property supports **QProperty**  bindings.

        This property holds the case sensitivity of the **QRegularExpression**
        pattern used to filter the contents of the source model.

        By default, the filter is case sensitive.

        **Note:** Setting this property propagates the new case sensitivity to
        the **filterRegularExpression**  property, and so breaks its binding.
        Likewise explicitly setting **filterRegularExpression**  changes the
        current case sensitivity, thereby breaking its binding.

        **See also** **filterRegularExpression**  and **sortCaseSensitivity** .
        """
        ...

    def setFilterKeyColumn(self, column: int) -> None:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#filterKeyColumn-prop

        **[bindable] filterKeyColumn : int**

        **Note:** This property supports **QProperty**  bindings.

        This property holds the column where the key used to filter the contents
        of the source model is read from.

        The default value is 0. If the value is -1, the keys will be read from
        all columns.
        """
        ...

    def filterKeyColumn(self) -> int:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#filterKeyColumn-prop

        **[bindable] filterKeyColumn : int**

        **Note:** This property supports **QProperty**  bindings.

        This property holds the column where the key used to filter the contents
        of the source model is read from.

        The default value is 0. If the value is -1, the keys will be read from
        all columns.
        """
        ...

    def filterRegularExpression(self) -> QRegularExpression:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#filterRegularExpressio
        n-prop

        **[bindable, since 5.12] filterRegularExpression : QRegularExpression**

        **Note:** This property supports **QProperty**  bindings.

        This property holds the **QRegularExpression**  used to filter the
        contents of the source model

        Setting this property through the **QRegularExpression**  overload
        overwrites the current **filterCaseSensitivity** . By default, the
        **QRegularExpression**  is an empty string matching all contents.

        If no **QRegularExpression**  or an empty string is set, everything in
        the source model will be accepted.

        **Note:** Setting this property propagates the case sensitivity of the
        new regular expression to the **filterCaseSensitivity**  property, and
        so breaks its binding. Likewise explicitly setting
        **filterCaseSensitivity**  changes the case sensitivity of the current
        regular expression, thereby breaking its binding.

        This property was introduced in Qt 5.12.

        **See also** **filterCaseSensitivity** , **setFilterWildcard** (), and
        **setFilterFixedString** ().
        """
        ...

    def mapSelectionFromSource(self, sourceSelection: QItemSelection) -> QItemSelection:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#mapSelectionFromSource

        **[override virtual] QItemSelection
        QSortFilterProxyModel::mapSelectionFromSource(const QItemSelection &
        sourceSelection ) const**

        Reimplements: **QAbstractProxyModel::mapSelectionFromSource(const
        QItemSelection &sourceSelection) const** .
        """
        ...

    def mapSelectionToSource(self, proxySelection: QItemSelection) -> QItemSelection:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#mapSelectionToSource

        **[override virtual] QItemSelection
        QSortFilterProxyModel::mapSelectionToSource(const QItemSelection &
        proxySelection ) const**

        Reimplements: **QAbstractProxyModel::mapSelectionToSource(const
        QItemSelection &proxySelection) const** .
        """
        ...

    def mapFromSource(self, sourceIndex: QModelIndex) -> QModelIndex:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#mapFromSource

        **[override virtual] QModelIndex
        QSortFilterProxyModel::mapFromSource(const QModelIndex & sourceIndex )
        const**

        Reimplements: **QAbstractProxyModel::mapFromSource(const QModelIndex
        &sourceIndex) const** .

        Returns the model index in the **QSortFilterProxyModel**  given the
        **sourceIndex** from the source model.

        **See also** **mapToSource** ().
        """
        ...

    def mapToSource(self, proxyIndex: QModelIndex) -> QModelIndex:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#mapToSource

        **[override virtual] QModelIndex
        QSortFilterProxyModel::mapToSource(const QModelIndex & proxyIndex )
        const**

        Reimplements: **QAbstractProxyModel::mapToSource(const QModelIndex
        &proxyIndex) const** .

        Returns the source model index corresponding to the given **proxyIndex**
        from the sorting filter model.

        **See also** **mapFromSource** ().
        """
        ...

    def setSourceModel(self, sourceModel: QAbstractItemModel) -> None:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#setSourceModel

        **[override virtual] void
        QSortFilterProxyModel::setSourceModel(QAbstractItemModel * sourceModel
        )**

        Reimplements: **QAbstractProxyModel::setSourceModel**
        (QAbstractItemModel *sourceModel).
        """
        ...

    @property
    def autoAcceptChildRowsChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#autoAcceptChildRowsCha
        nged

        **[signal, since 6.0] void
        QSortFilterProxyModel::autoAcceptChildRowsChanged(bool
        autoAcceptChildRows )**

        This signals is emitted when the value of the **autoAcceptChildRows**
        property is changed.

        **Note:** Notifier signal for property **autoAcceptChildRows** .

        This function was introduced in Qt 6.0.

        **See also** **autoAcceptChildRows** .
        """
        ...

    @property
    def filterCaseSensitivityChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#filterCaseSensitivityC
        hanged

        **[signal, since 5.15] void
        QSortFilterProxyModel::filterCaseSensitivityChanged(Qt::CaseSensitivity
        filterCaseSensitivity )**

        This signal is emitted when the case sensitivity of the filter changes
        to **filterCaseSensitivity**.

        **Note:** Notifier signal for property **filterCaseSensitivity** .

        This function was introduced in Qt 5.15.
        """
        ...

    @property
    def filterRoleChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#filterRoleChanged

        **[signal, since 5.15] void QSortFilterProxyModel::filterRoleChanged(int
        filterRole )**

        This signal is emitted when the filter role changes to **filterRole**.

        **Note:** Notifier signal for property **filterRole** .

        This function was introduced in Qt 5.15.
        """
        ...

    @property
    def recursiveFilteringEnabledChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#recursiveFilteringEnab
        ledChanged

        **[signal, since 5.15] void
        QSortFilterProxyModel::recursiveFilteringEnabledChanged(bool
        recursiveFilteringEnabled )**

        This signal is emitted when the recursive filter setting is changed to
        **recursiveFilteringEnabled**.

        **Note:** Notifier signal for property **recursiveFilteringEnabled** .

        This function was introduced in Qt 5.15.
        """
        ...

    @property
    def sortCaseSensitivityChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#sortCaseSensitivityCha
        nged

        **[signal, since 5.15] void
        QSortFilterProxyModel::sortCaseSensitivityChanged(Qt::CaseSensitivity
        sortCaseSensitivity )**

        This signal is emitted when the case sensitivity for sorting changes to
        **sortCaseSensitivity**.

        **Note:** Notifier signal for property **sortCaseSensitivity** .

        This function was introduced in Qt 5.15.
        """
        ...

    @property
    def sortLocaleAwareChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#sortLocaleAwareChanged

        **[signal, since 5.15] void
        QSortFilterProxyModel::sortLocaleAwareChanged(bool sortLocaleAware )**

        This signal is emitted when the locale aware setting changes to
        **sortLocaleAware**.

        **Note:** Notifier signal for property **isSortLocaleAware** .

        This function was introduced in Qt 5.15.
        """
        ...

    @property
    def sortRoleChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qsortfilterproxymodel.html#sortRoleChanged

        **[signal, since 5.15] void QSortFilterProxyModel::sortRoleChanged(int
        sortRole )**

        This signal is emitted when the sort role changes to **sortRole**.

        **Note:** Notifier signal for property **sortRole** .

        This function was introduced in Qt 5.15.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QTouchEvent(QPointerEvent):
    """
    https://doc.qt.io/qt-6/qtouchevent.html

    **Detailed Description**

    **Enabling Touch Events**

    Touch events occur when pressing, releasing, or moving one or more touch
    points on a touch device (such as a touch-screen or track-pad). To receive
    touch events, widgets have to have the **Qt::WA_AcceptTouchEvents**
    attribute set and graphics items need to have the **acceptTouchEvents**
    attribute set to true.

    When using **QAbstractScrollArea**  based widgets, you should enable the
    **Qt::WA_AcceptTouchEvents**  attribute on the scroll area's **viewport** .

    Similarly to **QMouseEvent** , Qt automatically grabs each touch point on
    the first press inside a widget, and the widget will receive all updates for
    the touch point until it is released. Note that it is possible for a widget
    to receive events for numerous touch points, and that multiple widgets may
    be receiving touch events at the same time.

    **Event Handling**

    All touch events are of type **QEvent::TouchBegin** ,
    **QEvent::TouchUpdate** , **QEvent::TouchEnd**  or **QEvent::TouchCancel** .
    Reimplement **QWidget::event** () or **QAbstractScrollArea::viewportEvent**
    () for widgets and **QGraphicsItem::sceneEvent** () for items in a graphics
    view to receive touch events.

    Unlike widgets, QWindows receive touch events always, there is no need to
    opt in. When working directly with a **QWindow** , it is enough to
    reimplement **QWindow::touchEvent** ().

    The **QEvent::TouchUpdate**  and **QEvent::TouchEnd**  events are sent to
    the widget or item that accepted the **QEvent::TouchBegin**  event. If the
    **QEvent::TouchBegin**  event is not accepted and not filtered by an event
    filter, then no further touch events are sent until the next
    **QEvent::TouchBegin** .

    Some systems may send an event of type **QEvent::TouchCancel** . Upon
    receiving this event applications are requested to ignore the entire active
    touch sequence. For example in a composited system the compositor may decide
    to treat certain gestures as system-wide gestures. Whenever such a decision
    is made (the gesture is recognized), the clients will be notified with a
    **QEvent::TouchCancel**  event so they can update their state accordingly.

    The **pointCount** () and **point** () functions can be used to access and
    iterate individual touch points.

    The **points** () function returns a list of all touch points contained in
    the event. Note that this list may be empty, for example in case of a
    **QEvent::TouchCancel**  event. Each point is an instance of the
    **QEventPoint**  class. The **QEventPoint::State**  enum describes the
    different states that a touch point may have.

    **Note:** The list of **points** () will never be partial: A touch event
    will always contain a touch point for each existing physical touch contacts
    targeting the window or widget to which the event is sent. For instance,
    assuming that all touches target the same window or widget, an event with a
    condition of **points** ().count()==2 is guaranteed to imply that the number
    of fingers touching the touchscreen or touchpad is exactly two.

    **Event Delivery and Propagation**

    By default, **QGuiApplication**  translates the first touch point in a
    QTouchEvent into a **QMouseEvent** . This makes it possible to enable touch
    events on existing widgets that do not normally handle QTouchEvent. See
    below for information on some special considerations needed when doing this.

    **QEvent::TouchBegin**  is the first touch event sent to a widget. The
    **QEvent::TouchBegin**  event contains a special accept flag that indicates
    whether the receiver wants the event. By default, the event is accepted. You
    should call **ignore** () if the touch event is not handled by your widget.
    The **QEvent::TouchBegin**  event is propagated up the parent widget chain
    until a widget accepts it with **accept** (), or an event filter consumes
    it. For QGraphicsItems, the **QEvent::TouchBegin**  event is propagated to
    items under the mouse (similar to mouse event propagation for
    QGraphicsItems).

    **Touch Point Grouping**

    As mentioned above, it is possible that several widgets can be receiving
    QTouchEvents at the same time. However, Qt makes sure to never send
    duplicate **QEvent::TouchBegin**  events to the same widget, which could
    theoretically happen during propagation if, for example, the user touched 2
    separate widgets in a **QGroupBox**  and both widgets ignored the
    **QEvent::TouchBegin**  event.

    To avoid this, Qt will group new touch points together using the following
    rules:

    * When the first touch point is detected, the destination widget is
    determined firstly by the location on screen and secondly by the propagation
    rules.
      * When additional touch points are detected, Qt first looks to see
    if there are any active touch points on any ancestor or descendent of the
    widget under the new touch point. If there are, the new touch point is
    grouped with the first, and the new touch point will be sent in a single
    QTouchEvent to the widget that handled the first touch point. (The widget
    under the new touch point will not receive an event).

    This makes it possible for sibling widgets to handle touch events
    independently while making sure that the sequence of QTouchEvents is always
    correct.

    **Mouse Events and Touch Event Synthesizing**

    QTouchEvent delivery is independent from that of **QMouseEvent** . The
    application flags **Qt::AA_SynthesizeTouchForUnhandledMouseEvents**  and
    **Qt::AA_SynthesizeMouseForUnhandledTouchEvents**  can be used to enable or
    disable automatic synthesizing of touch events to mouse events and mouse
    events to touch events.

    **Caveats**

    * As mentioned above, enabling touch events means multiple widgets can be
    receiving touch events simultaneously. Combined with the default
    **QWidget::event** () handling for QTouchEvents, this gives you great
    flexibility in designing touch user interfaces. Be aware of the
    implications. For example, it is possible that the user is moving a
    **QSlider**  with one finger and pressing a **QPushButton**  with another.
    The signals emitted by these widgets will be interleaved.
      * Recursion into
    the event loop using one of the exec() methods (e.g., **QDialog::exec** ()
    or **QMenu::exec** ()) in a QTouchEvent event handler is not supported.
    Since there are multiple event recipients, recursion may cause problems,
    including but not limited to lost events and unexpected infinite recursion.
    * QTouchEvents are not affected by a **mouse grab**  or an **active pop-up
    widget** . The behavior of QTouchEvents is undefined when opening a pop-up
    or grabbing the mouse while there are more than one active touch points.

    **See also** **QEventPoint** , **QEventPoint::State** ,
    **Qt::WA_AcceptTouchEvents** , and **QGraphicsItem::acceptTouchEvents** ().
    """

    def __init__(
        self,
        eventType: QtCore.QEvent.Type,
        device: typing.Optional["QPointingDevice"] = ...,
        modifiers: QtCore.Qt.KeyboardModifier = ...,
        touchPoints: typing.Iterable["QEventPoint"] = ...,
    ) -> None:
        ...

    def clone(self) -> "QTouchEvent":
        ...

    def isEndEvent(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtouchevent.html#isEndEvent

        **[override virtual] bool QTouchEvent::isEndEvent() const**

        Returns true if this event includes at least one newly-released
        touchpoint.
        """
        ...

    def isUpdateEvent(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtouchevent.html#isUpdateEvent

        **[override virtual] bool QTouchEvent::isUpdateEvent() const**

        Returns true if this event does not include newly-pressed or newly-
        released touchpoints.
        """
        ...

    def isBeginEvent(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtouchevent.html#isBeginEvent

        **[override virtual] bool QTouchEvent::isBeginEvent() const**

        Returns true if this event includes at least one newly-pressed
        touchpoint.
        """
        ...

    def touchPointStates(self) -> "QEventPoint.State":
        """
        https://doc.qt.io/qt-6/qtouchevent.html#touchPointStates

        **QEventPoint::States QTouchEvent::touchPointStates() const**

        Returns a bitwise OR of all the touch point states for this event.
        """
        ...

    def target(self) -> QtCore.QObject:
        """
        https://doc.qt.io/qt-6/qtouchevent.html#target

        **QObject *QTouchEvent::target() const**

        Returns the target object within the window on which the event occurred.
        This is typically a **QWidget**  or a **QQuickItem** . May be 0 when no
        specific target is available.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtNetwork import *
import enum


class QSslCertificate(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qsslcertificate.html

    **Detailed Description**

    QSslCertificate stores an X509 certificate, and is commonly used to verify
    the identity and store information about the local host, a remotely
    connected peer, or a trusted third party Certificate Authority.

    There are many ways to construct a QSslCertificate. The most common way is
    to call **QSslSocket::peerCertificate** (), which returns a QSslCertificate
    object, or **QSslSocket::peerCertificateChain** (), which returns a list of
    them. You can also load certificates from a DER (binary) or PEM (Base64)
    encoded bundle, typically stored as one or more local files, or in a Qt
    Resource.

    You can call **isNull** () to check if your certificate is null. By default,
    QSslCertificate constructs a null certificate. A null certificate is
    invalid, but an invalid certificate is not necessarily null. If you want to
    reset all contents in a certificate, call **clear** ().

    After loading a certificate, you can find information about the certificate,
    its subject, and its issuer, by calling one of the many accessor functions,
    including **version** (), **serialNumber** (), **issuerInfo** () and
    **subjectInfo** (). You can call **effectiveDate** () and **expiryDate** ()
    to check when the certificate starts being effective and when it expires.
    The **publicKey** () function returns the certificate subject's public key
    as a **QSslKey** . You can call **issuerInfo** () or **subjectInfo** () to
    get detailed information about the certificate issuer and its subject.

    Internally, QSslCertificate is stored as an X509 structure. You can access
    this handle by calling **handle** (), but the results are likely to not be
    portable.

    **See also** **QSslSocket** , **QSslKey** , **QSslCipher** , and
    **QSslError** .
    """

    class PatternSyntax(enum.Enum):
        RegularExpression: QSslCertificate = ...
        Wildcard: QSslCertificate = ...
        FixedString: QSslCertificate = ...

    class SubjectInfo(enum.Enum):
        Organization: QSslCertificate = ...
        CommonName: QSslCertificate = ...
        LocalityName: QSslCertificate = ...
        OrganizationalUnitName: QSslCertificate = ...
        CountryName: QSslCertificate = ...
        StateOrProvinceName: QSslCertificate = ...
        DistinguishedNameQualifier: QSslCertificate = ...
        SerialNumber: QSslCertificate = ...
        EmailAddress: QSslCertificate = ...

    @typing.overload
    def __init__(
        self, device: QtCore.QIODevice, format: QSsl.EncodingFormat = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsslcertificate.html#QSslCertificate

        **QSslCertificate::QSslCertificate(QIODevice * device ,
        QSsl::EncodingFormat format = QSsl::Pem)**

        Constructs a QSslCertificate by reading **format** encoded data from
        **device** and using the first certificate found. You can later call
        **isNull** () to see if **device** contained a certificate, and if this
        certificate was loaded successfully.
        """
        ...

    @typing.overload
    def __init__(
        self, data: QtCore.QByteArray = ..., format: QSsl.EncodingFormat = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsslcertificate.html#QSslCertificate-1

        **QSslCertificate::QSslCertificate(const QByteArray & data =
        QByteArray(), QSsl::EncodingFormat format = QSsl::Pem)**

        Constructs a QSslCertificate by parsing the **format** encoded **data**
        and using the first available certificate found. You can later call
        **isNull** () to see if **data** contained a certificate, and if this
        certificate was loaded successfully.
        """
        ...

    @typing.overload
    def __init__(self, other: "QSslCertificate") -> None:
        """
        https://doc.qt.io/qt-6/qsslcertificate.html#QSslCertificate-2

        **QSslCertificate::QSslCertificate(const QSslCertificate & other )**

        Constructs an identical copy of **other**.
        """
        ...

    def subjectDisplayName(self) -> str:
        """
        https://doc.qt.io/qt-6/qsslcertificate.html#subjectDisplayName

        **[since 5.12] QString QSslCertificate::subjectDisplayName() const**

        Returns a name that describes the subject. It returns the
        **QSslCertificate::CommonName**  if available, otherwise falls back to
        the first **QSslCertificate::Organization**  or the first
        **QSslCertificate::OrganizationalUnitName** .

        This function was introduced in Qt 5.12.

        **See also** **subjectInfo** ().
        """
        ...

    def issuerDisplayName(self) -> str:
        """
        https://doc.qt.io/qt-6/qsslcertificate.html#issuerDisplayName

        **[since 5.12] QString QSslCertificate::issuerDisplayName() const**

        Returns a name that describes the issuer. It returns the
        **QSslCertificate::CommonName**  if available, otherwise falls back to
        the first **QSslCertificate::Organization**  or the first
        **QSslCertificate::OrganizationalUnitName** .

        This function was introduced in Qt 5.12.

        **See also** **issuerInfo** ().
        """
        ...

    @staticmethod
    def importPkcs12(
        device: QtCore.QIODevice,
        key: "QSslKey",
        certificate: "QSslCertificate",
        caCertificates: typing.Optional[typing.Iterable["QSslCertificate"]] = ...,
        passPhrase: QtCore.QByteArray = ...,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qsslcertificate.html#importPkcs12

        **[static, since 5.4] bool QSslCertificate::importPkcs12(QIODevice *
        device , QSslKey * key , QSslCertificate * certificate ,
        QList<QSslCertificate> * caCertificates = nullptr, const QByteArray &
        passPhrase = QByteArray())**

        Imports a PKCS#12 (pfx) file from the specified **device**. A PKCS#12
        file is a bundle that can contain a number of certificates and keys.
        This method reads a single **key** , its **certificate** and any
        associated **caCertificates** from the bundle. If a **passPhrase** is
        specified then this will be used to decrypt the bundle. Returns `true`
        if the PKCS#12 file was successfully loaded.

        **Note:** The **device** must be open and ready to be read from.

        This function was introduced in Qt 5.4.
        """
        ...

    def __hash__(self) -> int:
        ...

    def isSelfSigned(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsslcertificate.html#isSelfSigned

        **[since 5.4] bool QSslCertificate::isSelfSigned() const**

        Returns `true` if this certificate is self signed; otherwise returns
        `false`.

        A certificate is considered self-signed its issuer and subject are
        identical.

        This function was introduced in Qt 5.4.
        """
        ...

    @staticmethod
    def verify(
        certificateChain: typing.Iterable["QSslCertificate"], hostName: str = ...
    ) -> typing.List["QSslError"]:
        """
        https://doc.qt.io/qt-6/qsslcertificate.html#verify

        **[static, since 5.0] QList<QSslError> QSslCertificate::verify(const
        QList<QSslCertificate> & certificateChain , const QString & hostName =
        QString())**

        Verifies a certificate chain. The chain to be verified is passed in the
        **certificateChain** parameter. The first certificate in the list should
        be the leaf certificate of the chain to be verified. If **hostName** is
        specified then the certificate is also checked to see if it is valid for
        the specified host name.

        Note that the root (CA) certificate should not be included in the list
        to be verified, this will be looked up automatically using the CA list
        specified in the default **QSslConfiguration** , and, in addition, if
        possible, CA certificates loaded on demand on Unix and Windows.

        This function was introduced in Qt 5.0.
        """
        ...

    def toText(self) -> str:
        """
        https://doc.qt.io/qt-6/qsslcertificate.html#toText

        **[since 5.0] QString QSslCertificate::toText() const**

        Returns this certificate converted to a human-readable text
        representation.

        This function was introduced in Qt 5.0.
        """
        ...

    def extensions(self) -> typing.List["QSslCertificateExtension"]:
        """
        https://doc.qt.io/qt-6/qsslcertificate.html#extensions

        **[since 5.0] QList<QSslCertificateExtension>
        QSslCertificate::extensions() const**

        Returns a list containing the X509 extensions of this certificate.

        This function was introduced in Qt 5.0.
        """
        ...

    def issuerInfoAttributes(self) -> typing.List[QtCore.QByteArray]:
        """
        https://doc.qt.io/qt-6/qsslcertificate.html#issuerInfoAttributes

        **[since 5.0] QList<QByteArray> QSslCertificate::issuerInfoAttributes()
        const**

        Returns a list of the attributes that have values in the issuer
        information of this certificate. The information associated with a given
        attribute can be accessed using the **issuerInfo** () method. Note that
        this list may include the OIDs for any elements that are not known by
        the SSL backend.

        This function was introduced in Qt 5.0.

        **See also** **subjectInfo** ().
        """
        ...

    def subjectInfoAttributes(self) -> typing.List[QtCore.QByteArray]:
        """
        https://doc.qt.io/qt-6/qsslcertificate.html#subjectInfoAttributes

        **[since 5.0] QList<QByteArray> QSslCertificate::subjectInfoAttributes()
        const**

        Returns a list of the attributes that have values in the subject
        information of this certificate. The information associated with a given
        attribute can be accessed using the **subjectInfo** () method. Note that
        this list may include the OIDs for any elements that are not known by
        the SSL backend.

        This function was introduced in Qt 5.0.

        **See also** **subjectInfo** ().
        """
        ...

    def isBlacklisted(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsslcertificate.html#isBlacklisted

        **bool QSslCertificate::isBlacklisted() const**

        Returns `true` if this certificate is blacklisted; otherwise returns
        `false`.

        **See also** **isNull** ().
        """
        ...

    def swap(self, other: "QSslCertificate") -> None:
        """
        https://doc.qt.io/qt-6/qsslcertificate.html#swap

        **[since 5.0] void QSslCertificate::swap(QSslCertificate & other )**

        Swaps this certificate instance with **other**. This function is very
        fast and never fails.

        This function was introduced in Qt 5.0.
        """
        ...

    def handle(self) -> PyQt6.sip.voidptr:
        """
        https://doc.qt.io/qt-6/qsslcertificate.html#handle

        **Qt::HANDLE QSslCertificate::handle() const**

        Returns a pointer to the native certificate handle, if there is one,
        else `nullptr`.

        You can use this handle, together with the native API, to access
        extended information about the certificate.

        **Warning:** Use of this function has a high probability of being non-
        portable, and its return value may vary from platform to platform or
        change from minor release to minor release.
        """
        ...

    @staticmethod
    def fromData(
        data: QtCore.QByteArray, format: QSsl.EncodingFormat = ...
    ) -> typing.List["QSslCertificate"]:
        """
        https://doc.qt.io/qt-6/qsslcertificate.html#fromData

        **[static] QList<QSslCertificate> QSslCertificate::fromData(const
        QByteArray & data , QSsl::EncodingFormat format = QSsl::Pem)**

        Searches for and parses all certificates in **data** that are encoded in
        the specified **format** and returns them in a list of certificates.

        **See also** **fromDevice** ().
        """
        ...

    @staticmethod
    def fromDevice(
        device: QtCore.QIODevice, format: QSsl.EncodingFormat = ...
    ) -> typing.List["QSslCertificate"]:
        """
        https://doc.qt.io/qt-6/qsslcertificate.html#fromDevice

        **[static] QList<QSslCertificate> QSslCertificate::fromDevice(QIODevice
        * device , QSsl::EncodingFormat format = QSsl::Pem)**

        Searches for and parses all certificates in **device** that are encoded
        in the specified **format** and returns them in a list of certificates.

        **See also** **fromData** ().
        """
        ...

    @staticmethod
    def fromPath(
        path: str,
        format: QSsl.EncodingFormat = ...,
        syntax: "QSslCertificate.PatternSyntax" = ...,
    ) -> typing.List["QSslCertificate"]:
        """
        https://doc.qt.io/qt-6/qsslcertificate.html#fromPath

        **[static, since 5.15] QList<QSslCertificate>
        QSslCertificate::fromPath(const QString & path , QSsl::EncodingFormat
        format = QSsl::Pem, QSslCertificate::PatternSyntax syntax =
        PatternSyntax::FixedString)**

        Searches all files in the **path** for certificates encoded in the
        specified **format** and returns them in a list. **path** must be a file
        or a pattern matching one or more files, as specified by **syntax**.

        Example:

        const auto certs = **QSslCertificate**
        ::fromPath("C:/ssl/certificate.*.pem",
        QSsl::Pem, **QSslCertificate** ::Wildcard);
            for (const
        **QSslCertificate**  &cert : certs) {
                **qDebug** () <<
        cert.issuerInfo(**QSslCertificate** ::Organization);
            }

        This function was introduced in Qt 5.15.

        **See also** **fromData** ().
        """
        ...

    def toDer(self) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qsslcertificate.html#toDer

        **QByteArray QSslCertificate::toDer() const**

        Returns this certificate converted to a DER (binary) encoded
        representation.
        """
        ...

    def toPem(self) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qsslcertificate.html#toPem

        **QByteArray QSslCertificate::toPem() const**

        Returns this certificate converted to a PEM (Base64) encoded
        representation.
        """
        ...

    def publicKey(self) -> "QSslKey":
        """
        https://doc.qt.io/qt-6/qsslcertificate.html#publicKey

        **QSslKey QSslCertificate::publicKey() const**

        Returns the certificate subject's public key.
        """
        ...

    def expiryDate(self) -> QtCore.QDateTime:
        """
        https://doc.qt.io/qt-6/qsslcertificate.html#expiryDate

        **QDateTime QSslCertificate::expiryDate() const**

        Returns the date-time that the certificate expires, or an empty
        **QDateTime**  if this is a null certificate.

        **See also** **effectiveDate** ().
        """
        ...

    def effectiveDate(self) -> QtCore.QDateTime:
        """
        https://doc.qt.io/qt-6/qsslcertificate.html#effectiveDate

        **QDateTime QSslCertificate::effectiveDate() const**

        Returns the date-time that the certificate becomes valid, or an empty
        **QDateTime**  if this is a null certificate.

        **See also** **expiryDate** ().
        """
        ...

    def subjectAlternativeNames(
        self,
    ) -> typing.Dict[QSsl.AlternativeNameEntryType, typing.List[str]]:
        """
        https://doc.qt.io/qt-6/qsslcertificate.html#subjectAlternativeNames

        **QMultiMap<QSsl::AlternativeNameEntryType, QString>
        QSslCertificate::subjectAlternativeNames() const**

        Returns the list of alternative subject names for this certificate. The
        alternative names typically contain host names, optionally with
        wildcards, that are valid for this certificate.

        These names are tested against the connected peer's host name, if either
        the subject information for **CommonName**  doesn't define a valid host
        name, or the subject info name doesn't match the peer's host name.

        **See also** **subjectInfo** ().
        """
        ...

    @typing.overload
    def subjectInfo(self, info: "QSslCertificate.SubjectInfo") -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qsslcertificate.html#subjectInfo

        **QStringList QSslCertificate::subjectInfo(QSslCertificate::SubjectInfo
        subject ) const**

        Returns the information for the **subject** , or an empty list if there
        is no information for **subject** in the certificate. There can be more
        than one entry of each type.

        **See also** **issuerInfo** ().
        """
        ...

    @typing.overload
    def subjectInfo(self, attribute: QtCore.QByteArray) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qsslcertificate.html#subjectInfo-1

        **QStringList QSslCertificate::subjectInfo(const QByteArray & attribute
        ) const**

        Returns the subject information for **attribute** , or an empty list if
        there is no information for **attribute** in the certificate. There can
        be more than one entry for an attribute.

        **See also** **issuerInfo** ().
        """
        ...

    @typing.overload
    def issuerInfo(self, info: "QSslCertificate.SubjectInfo") -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qsslcertificate.html#issuerInfo

        **QStringList QSslCertificate::issuerInfo(QSslCertificate::SubjectInfo
        subject ) const**

        Returns the issuer information for the **subject** from the certificate,
        or an empty list if there is no information for **subject** in the
        certificate. There can be more than one entry of each type.

        **See also** **subjectInfo** ().
        """
        ...

    @typing.overload
    def issuerInfo(self, attribute: QtCore.QByteArray) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qsslcertificate.html#issuerInfo-1

        **QStringList QSslCertificate::issuerInfo(const QByteArray & attribute )
        const**

        Returns the issuer information for **attribute** from the certificate,
        or an empty list if there is no information for **attribute** in the
        certificate. There can be more than one entry for an attribute.

        **See also** **subjectInfo** ().
        """
        ...

    def digest(
        self, algorithm: QtCore.QCryptographicHash.Algorithm = ...
    ) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qsslcertificate.html#digest

        **QByteArray QSslCertificate::digest(QCryptographicHash::Algorithm
        algorithm = QCryptographicHash::Md5) const**

        Returns a cryptographic digest of this certificate. By default, an MD5
        digest will be generated, but you can also specify a custom
        **algorithm**.
        """
        ...

    def serialNumber(self) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qsslcertificate.html#serialNumber

        **QByteArray QSslCertificate::serialNumber() const**

        Returns the certificate's serial number string in hexadecimal format.
        """
        ...

    def version(self) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qsslcertificate.html#version

        **QByteArray QSslCertificate::version() const**

        Returns the certificate's version string.
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qsslcertificate.html#clear

        **void QSslCertificate::clear()**

        Clears the contents of this certificate, making it a null certificate.

        **See also** **isNull** ().
        """
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsslcertificate.html#isNull

        **bool QSslCertificate::isNull() const**

        Returns `true` if this is a null certificate (i.e., a certificate with
        no contents); otherwise returns `false`.

        By default, **QSslCertificate**  constructs a null certificate.

        **See also** **clear** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtCore import *


class QAbstractTableModel(QAbstractItemModel):
    """
    https://doc.qt.io/qt-6/qabstracttablemodel.html

    **Detailed Description**

    QAbstractTableModel provides a standard interface for models that represent
    their data as a two-dimensional array of items. It is not used directly, but
    must be subclassed.

    Since the model provides a more specialized interface than
    **QAbstractItemModel** , it is not suitable for use with tree views,
    although it can be used to provide data to a **QListView** . If you need to
    represent a simple list of items, and only need a model to contain a single
    column of data, subclassing the **QAbstractListModel**  may be more
    appropriate.

    The **rowCount** () and **columnCount** () functions return the dimensions
    of the table. To retrieve a model index corresponding to an item in the
    model, use **index** () and provide only the row and column numbers.

    **Subclassing**

    When subclassing QAbstractTableModel, you must implement **rowCount** (),
    **columnCount** (), and **data** (). Default implementations of the
    **index** () and **parent** () functions are provided by
    QAbstractTableModel. Well behaved models will also implement **headerData**
    ().

    Editable models need to implement **setData** (), and implement **flags** ()
    to return a value containing **Qt::ItemIsEditable** .

    Models that provide interfaces to resizable data structures can provide
    implementations of **insertRows** (), **removeRows** (), **insertColumns**
    (), and **removeColumns** (). When implementing these functions, it is
    important to call the appropriate functions so that all connected views are
    aware of any changes:

    * An **insertRows** () implementation must call **beginInsertRows** ()
    **before** inserting new rows into the data structure, and it must call
    **endInsertRows** () **immediately afterwards**.
      * An **insertColumns** ()
    implementation must call **beginInsertColumns** () **before** inserting new
    columns into the data structure, and it must call **endInsertColumns** ()
    **immediately afterwards**.
      * A **removeRows** () implementation must call
    **beginRemoveRows** () **before** the rows are removed from the data
    structure, and it must call **endRemoveRows** () **immediately afterwards**.
    * A **removeColumns** () implementation must call **beginRemoveColumns** ()
    **before** the columns are removed from the data structure, and it must call
    **endRemoveColumns** () **immediately afterwards**.

    **Note:** Some general guidelines for subclassing models are available in
    the **Model Subclassing Reference** .

    **See also** **Model Classes** , **QAbstractItemModel** ,
    **QAbstractListModel** , and **Pixelator Example** .
    """

    def __init__(self, parent: typing.Optional[QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qabstracttablemodel.html#QAbstractTableModel

        **QAbstractTableModel::QAbstractTableModel(QObject * parent = nullptr)**

        Constructs an abstract table model for the given **parent**.
        """
        ...

    def sibling(self, row: int, column: int, idx: QModelIndex) -> QModelIndex:
        """
        https://doc.qt.io/qt-6/qabstracttablemodel.html#sibling

        **[override virtual] QModelIndex QAbstractTableModel::sibling(int row ,
        int column , const QModelIndex & idx ) const**

        Reimplements: **QAbstractItemModel::sibling(int row, int column, const
        QModelIndex &index) const** .
        """
        ...

    def parent(self) -> QObject:
        ...

    def flags(self, index: QModelIndex) -> Qt.ItemFlag:
        """
        https://doc.qt.io/qt-6/qabstracttablemodel.html#flags

        **[override virtual] Qt::ItemFlags QAbstractTableModel::flags(const
        QModelIndex & index ) const**

        Reimplements: **QAbstractItemModel::flags(const QModelIndex &index)
        const** .
        """
        ...

    def dropMimeData(
        self,
        data: "QMimeData",
        action: Qt.DropAction,
        row: int,
        column: int,
        parent: QModelIndex,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qabstracttablemodel.html#dropMimeData

        **[override virtual] bool QAbstractTableModel::dropMimeData(const
        QMimeData * data , Qt::DropAction action , int row , int column , const
        QModelIndex & parent )**

        Reimplements: **QAbstractItemModel::dropMimeData** (const QMimeData
        *data, Qt::DropAction action, int row, int column, const QModelIndex
        &parent).
        """
        ...

    def index(self, row: int, column: int, parent: QModelIndex = ...) -> QModelIndex:
        """
        https://doc.qt.io/qt-6/qabstracttablemodel.html#index

        **[override virtual] QModelIndex QAbstractTableModel::index(int row ,
        int column , const QModelIndex & parent = QModelIndex()) const**

        Reimplements: **QAbstractItemModel::index(int row, int column, const
        QModelIndex &parent) const** .

        Returns the index of the data in **row** and **column** with **parent**.

        **See also** **parent** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QMatrix4x4(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qmatrix4x4.html

    **Detailed Description**

    The QMatrix4x4 class in general is treated as a row-major matrix, in that
    the constructors and **operator** () functions take data in row-major
    format, as is familiar in C-style usage.

    Internally the data is stored as column-major format, so as to be optimal
    for passing to OpenGL functions, which expect column-major data.

    When using these functions be aware that they return data in **column-
    major** format:

    * **data** ()
      * **constData** ()

    **See also** **QVector3D**  and **QGenericMatrix** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qmatrix4x4.html#QMatrix4x4

        **QMatrix4x4::QMatrix4x4()**

        Constructs an identity matrix.
        """
        ...

    @typing.overload
    def __init__(self, values: typing.Sequence[float]) -> None:
        """
        https://doc.qt.io/qt-6/qmatrix4x4.html#QMatrix4x4-2

        **QMatrix4x4::QMatrix4x4(const float * values )**

        Constructs a matrix from the given 16 floating-point **values**. The
        contents of the array **values** is assumed to be in row-major order.

        If the matrix has a special type (identity, translate, scale, etc), the
        programmer should follow this constructor with a call to **optimize** ()
        if they wish QMatrix4x4 to optimize further calls to **translate** (),
        **scale** (), etc.

        **See also** **copyDataTo** () and **optimize** ().
        """
        ...

    @typing.overload
    def __init__(
        self,
        m11: float,
        m12: float,
        m13: float,
        m14: float,
        m21: float,
        m22: float,
        m23: float,
        m24: float,
        m31: float,
        m32: float,
        m33: float,
        m34: float,
        m41: float,
        m42: float,
        m43: float,
        m44: float,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qmatrix4x4.html#QMatrix4x4-3

        **QMatrix4x4::QMatrix4x4(float m11 , float m12 , float m13 , float m14 ,
        float m21 , float m22 , float m23 , float m24 , float m31 , float m32 ,
        float m33 , float m34 , float m41 , float m42 , float m43 , float m44
        )**

        Constructs a matrix from the 16 elements **m11** , **m12** , **m13** ,
        **m14** , **m21** , **m22** , **m23** , **m24** , **m31** , **m32** ,
        **m33** , **m34** , **m41** , **m42** , **m43** , and **m44**. The
        elements are specified in row-major order.

        If the matrix has a special type (identity, translate, scale, etc), the
        programmer should follow this constructor with a call to **optimize** ()
        if they wish QMatrix4x4 to optimize further calls to **translate** (),
        **scale** (), etc.

        **See also** **optimize** ().
        """
        ...

    @typing.overload
    def __init__(self, transform: "QTransform") -> None:
        """
        https://doc.qt.io/qt-6/qmatrix4x4.html#QMatrix4x4-4

        **template <int N, int M> QMatrix4x4::QMatrix4x4(const QGenericMatrix<N,
        M, float> & matrix = N)**

        Constructs a 4x4 matrix from the left-most 4 columns and top-most 4 rows
        of **matrix**. If **matrix** has less than 4 columns or rows, the
        remaining elements are filled with elements from the identity matrix.

        **See also** **toGenericMatrix** ().
        """
        ...

    @typing.overload
    def __init__(self, a0: "QMatrix4x4") -> None:
        """
        https://doc.qt.io/qt-6/qmatrix4x4.html#QMatrix4x4

        **QMatrix4x4::QMatrix4x4()**

        Constructs an identity matrix.
        """
        ...

    def __neg__(self) -> "QMatrix4x4":
        ...

    def isAffine(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmatrix4x4.html#isAffine

        **[since 5.5] bool QMatrix4x4::isAffine() const**

        Returns `true` if this matrix is affine matrix; false otherwise.

        An affine matrix is a 4x4 matrix with row 3 equal to (0, 0, 0, 1), e.g.
        no projective coefficients.

        This function was introduced in Qt 5.5.

        **See also** **isIdentity** ().
        """
        ...

    @typing.overload
    def viewport(
        self,
        left: float,
        bottom: float,
        width: float,
        height: float,
        nearPlane: float = ...,
        farPlane: float = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qmatrix4x4.html#viewport

        **void QMatrix4x4::viewport(float left , float bottom , float width ,
        float height , float nearPlane = 0.0f, float farPlane = 1.0f)**

        Multiplies this matrix by another that performs the scale and bias
        transformation used by OpenGL to transform from normalized device
        coordinates (NDC) to viewport (window) coordinates. That is it maps
        points from the cube ranging over [-1, 1] in each dimension to the
        viewport with it's near-lower-left corner at ( **left** , **bottom** ,
        **nearPlane** ) and with size ( **width** , **height** , **farPlane** \\-
        **nearPlane** ).

        This matches the transform used by the fixed function OpenGL viewport
        transform controlled by the functions glViewport() and glDepthRange().
        """
        ...

    @typing.overload
    def viewport(self, rect: QtCore.QRectF) -> None:
        """
        https://doc.qt.io/qt-6/qmatrix4x4.html#viewport-1

        **void QMatrix4x4::viewport(const QRectF & rect )**

        This is an overloaded function.

        Sets up viewport transform for viewport bounded by **rect** and with
        near and far set to 0 and 1 respectively.
        """
        ...

    def mapVector(self, vector: "QVector3D") -> "QVector3D":
        """
        https://doc.qt.io/qt-6/qmatrix4x4.html#mapVector

        **QVector3D QMatrix4x4::mapVector(const QVector3D & vector ) const**

        Maps **vector** by multiplying the top 3x3 portion of this matrix by
        **vector**. The translation and projection components of this matrix are
        ignored. The matrix is applied pre-vector.

        **See also** **map** ().
        """
        ...

    @typing.overload
    def map(self, point: QtCore.QPoint) -> QtCore.QPoint:
        """
        https://doc.qt.io/qt-6/qmatrix4x4.html#map

        **QPoint QMatrix4x4::map(const QPoint & point ) const**

        Maps **point** by multiplying this matrix by **point**. The matrix is
        applied pre-point.

        **See also** **mapRect** ().
        """
        ...

    @typing.overload
    def map(self, point: QtCore.QPointF) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qmatrix4x4.html#map-1

        **QPointF QMatrix4x4::map(const QPointF & point ) const**

        Maps **point** by post-multiplying this matrix by **point**. The matrix
        is applied pre-point.

        **See also** **mapRect** ().
        """
        ...

    @typing.overload
    def map(self, point: "QVector3D") -> "QVector3D":
        """
        https://doc.qt.io/qt-6/qmatrix4x4.html#map-2

        **QVector3D QMatrix4x4::map(const QVector3D & point ) const**

        Maps **point** by multiplying this matrix by **point**. The matrix is
        applied pre-point.

        **See also** **mapRect** () and **mapVector** ().
        """
        ...

    @typing.overload
    def map(self, point: "QVector4D") -> "QVector4D":
        """
        https://doc.qt.io/qt-6/qmatrix4x4.html#map-3

        **QVector4D QMatrix4x4::map(const QVector4D & point ) const**

        Maps **point** by multiplying this matrix by **point**. The matrix is
        applied pre-point.

        **See also** **mapRect** ().
        """
        ...

    def fill(self, value: float) -> None:
        """
        https://doc.qt.io/qt-6/qmatrix4x4.html#fill

        **void QMatrix4x4::fill(float value )**

        Fills all elements of this matrx with **value**.
        """
        ...

    def setToIdentity(self) -> None:
        """
        https://doc.qt.io/qt-6/qmatrix4x4.html#setToIdentity

        **void QMatrix4x4::setToIdentity()**

        Sets this matrix to the identity.

        **See also** **isIdentity** ().
        """
        ...

    def isIdentity(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmatrix4x4.html#isIdentity

        **bool QMatrix4x4::isIdentity() const**

        Returns `true` if this matrix is the identity; false otherwise.

        **See also** **setToIdentity** ().
        """
        ...

    def setRow(self, index: int, value: "QVector4D") -> None:
        """
        https://doc.qt.io/qt-6/qmatrix4x4.html#setRow

        **void QMatrix4x4::setRow(int index , const QVector4D & value )**

        Sets the elements of row **index** to the components of **value**.

        **See also** **row** () and **setColumn** ().
        """
        ...

    def row(self, index: int) -> "QVector4D":
        """
        https://doc.qt.io/qt-6/qmatrix4x4.html#row

        **QVector4D QMatrix4x4::row(int index ) const**

        Returns the elements of row **index** as a 4D vector.

        **See also** **setRow** () and **column** ().
        """
        ...

    def setColumn(self, index: int, value: "QVector4D") -> None:
        """
        https://doc.qt.io/qt-6/qmatrix4x4.html#setColumn

        **void QMatrix4x4::setColumn(int index , const QVector4D & value )**

        Sets the elements of column **index** to the components of **value**.

        **See also** **column** () and **setRow** ().
        """
        ...

    def column(self, index: int) -> "QVector4D":
        """
        https://doc.qt.io/qt-6/qmatrix4x4.html#column

        **QVector4D QMatrix4x4::column(int index ) const**

        Returns the elements of column **index** as a 4D vector.

        **See also** **setColumn** () and **row** ().
        """
        ...

    def __setitem__(self, a0: typing.Any, a1: float) -> None:
        ...

    def __getitem__(self, a0: typing.Any) -> typing.Any:
        ...

    def optimize(self) -> None:
        """
        https://doc.qt.io/qt-6/qmatrix4x4.html#optimize

        **void QMatrix4x4::optimize()**

        Optimize the usage of this matrix from its current elements.

        Some operations such as **translate** (), **scale** (), and **rotate**
        () can be performed more efficiently if the matrix being modified is
        already known to be the identity, a previous **translate** (), a
        previous **scale** (), etc.

        Normally the **QMatrix4x4**  class keeps track of this special type
        internally as operations are performed. However, if the matrix is
        modified directly with **operator** ()(int, int) or **data** (), then
        **QMatrix4x4**  will lose track of the special type and will revert to
        the safest but least efficient operations thereafter.

        By calling optimize() after directly modifying the matrix, the
        programmer can force **QMatrix4x4**  to recover the special type if the
        elements appear to conform to one of the known optimized types.

        **See also** **operator()** (int, int), **data** (), and **translate**
        ().
        """
        ...

    def data(self) -> typing.List[float]:
        """
        https://doc.qt.io/qt-6/qmatrix4x4.html#data

        **float *QMatrix4x4::data()**

        Returns a pointer to the raw data of this matrix.

        **See also** **constData** () and **optimize** ().
        """
        ...

    @typing.overload
    def mapRect(self, rect: QtCore.QRect) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qmatrix4x4.html#mapRect

        **QRect QMatrix4x4::mapRect(const QRect & rect ) const**

        Maps **rect** by multiplying this matrix by the corners of **rect** and
        then forming a new rectangle from the results. The returned rectangle
        will be an ordinary 2D rectangle with sides parallel to the horizontal
        and vertical axes.

        **See also** **map** ().
        """
        ...

    @typing.overload
    def mapRect(self, rect: QtCore.QRectF) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qmatrix4x4.html#mapRect-1

        **QRectF QMatrix4x4::mapRect(const QRectF & rect ) const**

        Maps **rect** by multiplying this matrix by the corners of **rect** and
        then forming a new rectangle from the results. The returned rectangle
        will be an ordinary 2D rectangle with sides parallel to the horizontal
        and vertical axes.

        **See also** **map** ().
        """
        ...

    @typing.overload
    def toTransform(self) -> "QTransform":
        """
        https://doc.qt.io/qt-6/qmatrix4x4.html#toTransform

        **QTransform QMatrix4x4::toTransform() const**

        Returns the conventional Qt 2D transformation matrix that corresponds to
        this matrix.

        The returned **QTransform**  is formed by simply dropping the third row
        and third column of the **QMatrix4x4** . This is suitable for
        implementing orthographic projections where the z coordinate should be
        dropped rather than projected.
        """
        ...

    @typing.overload
    def toTransform(self, distanceToPlane: float) -> "QTransform":
        """
        https://doc.qt.io/qt-6/qmatrix4x4.html#toTransform-1

        **QTransform QMatrix4x4::toTransform(float distanceToPlane ) const**

        Returns the conventional Qt 2D transformation matrix that corresponds to
        this matrix.

        If **distanceToPlane** is non-zero, it indicates a projection factor to
        use to adjust for the z coordinate. The value of 1024 corresponds to the
        projection factor used by **QTransform::rotate** () for the x and y
        axes.

        If **distanceToPlane** is zero, then the returned **QTransform**  is
        formed by simply dropping the third row and third column of the
        **QMatrix4x4** . This is suitable for implementing orthographic
        projections where the z coordinate should be dropped rather than
        projected.
        """
        ...

    def copyDataTo(self) -> typing.List[float]:
        """
        https://doc.qt.io/qt-6/qmatrix4x4.html#copyDataTo

        **void QMatrix4x4::copyDataTo(float * values ) const**

        Retrieves the 16 items in this matrix and copies them to **values** in
        row-major order.
        """
        ...

    def lookAt(self, eye: "QVector3D", center: "QVector3D", up: "QVector3D") -> None:
        """
        https://doc.qt.io/qt-6/qmatrix4x4.html#lookAt

        **void QMatrix4x4::lookAt(const QVector3D & eye , const QVector3D &
        center , const QVector3D & up )**

        Multiplies this matrix by a viewing matrix derived from an eye point.
        The **center** value indicates the center of the view that the **eye**
        is looking at. The **up** value indicates which direction should be
        considered up with respect to the **eye**.

        **Note:** The **up** vector must not be parallel to the line of sight
        from **eye** to **center**.
        """
        ...

    def perspective(
        self, angle: float, aspect: float, nearPlane: float, farPlane: float
    ) -> None:
        """
        https://doc.qt.io/qt-6/qmatrix4x4.html#perspective

        **void QMatrix4x4::perspective(float verticalAngle , float aspectRatio ,
        float nearPlane , float farPlane )**

        Multiplies this matrix by another that applies a perspective projection.
        The vertical field of view will be **verticalAngle** degrees within a
        window with a given **aspectRatio** that determines the horizontal field
        of view. The projection will have the specified **nearPlane** and
        **farPlane** clipping planes which are the distances from the viewer to
        the corresponding planes.

        **See also** **ortho** () and **frustum** ().
        """
        ...

    def frustum(
        self,
        left: float,
        right: float,
        bottom: float,
        top: float,
        nearPlane: float,
        farPlane: float,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qmatrix4x4.html#frustum

        **void QMatrix4x4::frustum(float left , float right , float bottom ,
        float top , float nearPlane , float farPlane )**

        Multiplies this matrix by another that applies a perspective frustum
        projection for a window with lower-left corner ( **left** , **bottom**
        ), upper-right corner ( **right** , **top** ), and the specified
        **nearPlane** and **farPlane** clipping planes.

        **See also** **ortho** () and **perspective** ().
        """
        ...

    @typing.overload
    def ortho(self, rect: QtCore.QRect) -> None:
        """
        https://doc.qt.io/qt-6/qmatrix4x4.html#ortho

        **void QMatrix4x4::ortho(float left , float right , float bottom , float
        top , float nearPlane , float farPlane )**

        Multiplies this matrix by another that applies an orthographic
        projection for a window with lower-left corner ( **left** , **bottom**
        ), upper-right corner ( **right** , **top** ), and the specified
        **nearPlane** and **farPlane** clipping planes.

        **See also** **frustum** () and **perspective** ().
        """
        ...

    @typing.overload
    def ortho(self, rect: QtCore.QRectF) -> None:
        """
        https://doc.qt.io/qt-6/qmatrix4x4.html#ortho-1

        **void QMatrix4x4::ortho(const QRect & rect )**

        This is an overloaded function.

        Multiplies this matrix by another that applies an orthographic
        projection for a window with boundaries specified by **rect**. The near
        and far clipping planes will be -1 and 1 respectively.

        **See also** **frustum** () and **perspective** ().
        """
        ...

    @typing.overload
    def ortho(
        self,
        left: float,
        right: float,
        bottom: float,
        top: float,
        nearPlane: float,
        farPlane: float,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qmatrix4x4.html#ortho-2

        **void QMatrix4x4::ortho(const QRectF & rect )**

        This is an overloaded function.

        Multiplies this matrix by another that applies an orthographic
        projection for a window with boundaries specified by **rect**. The near
        and far clipping planes will be -1 and 1 respectively.

        **See also** **frustum** () and **perspective** ().
        """
        ...

    @typing.overload
    def rotate(self, angle: float, vector: "QVector3D") -> None:
        """
        https://doc.qt.io/qt-6/qmatrix4x4.html#rotate

        **void QMatrix4x4::rotate(float angle , const QVector3D & vector )**

        Multiples this matrix by another that rotates coordinates through
        **angle** degrees about **vector**.

        **See also** **scale** () and **translate** ().
        """
        ...

    @typing.overload
    def rotate(self, angle: float, x: float, y: float, z: float = ...) -> None:
        """
        https://doc.qt.io/qt-6/qmatrix4x4.html#rotate-1

        **void QMatrix4x4::rotate(float angle , float x , float y , float z =
        0.0f)**

        This is an overloaded function.

        Multiplies this matrix by another that rotates coordinates through
        **angle** degrees about the vector ( **x** , **y** , **z** ).

        **See also** **scale** () and **translate** ().
        """
        ...

    @typing.overload
    def rotate(self, quaternion: "QQuaternion") -> None:
        """
        https://doc.qt.io/qt-6/qmatrix4x4.html#rotate-2

        **void QMatrix4x4::rotate(const QQuaternion & quaternion )**

        Multiples this matrix by another that rotates coordinates according to a
        specified **quaternion**. The **quaternion** is assumed to have been
        normalized.

        **See also** **scale** (), **translate** (), and **QQuaternion** .
        """
        ...

    @typing.overload
    def translate(self, vector: "QVector3D") -> None:
        """
        https://doc.qt.io/qt-6/qmatrix4x4.html#translate

        **void QMatrix4x4::translate(const QVector3D & vector )**

        Multiplies this matrix by another that translates coordinates by the
        components of **vector**.

        **See also** **scale** () and **rotate** ().
        """
        ...

    @typing.overload
    def translate(self, x: float, y: float) -> None:
        """
        https://doc.qt.io/qt-6/qmatrix4x4.html#translate-1

        **void QMatrix4x4::translate(float x , float y )**

        This is an overloaded function.

        Multiplies this matrix by another that translates coordinates by the
        components **x** , and **y**.

        **See also** **scale** () and **rotate** ().
        """
        ...

    @typing.overload
    def translate(self, x: float, y: float, z: float) -> None:
        """
        https://doc.qt.io/qt-6/qmatrix4x4.html#translate-2

        **void QMatrix4x4::translate(float x , float y , float z )**

        This is an overloaded function.

        Multiplies this matrix by another that translates coordinates by the
        components **x** , **y** , and **z**.

        **See also** **scale** () and **rotate** ().
        """
        ...

    @typing.overload
    def scale(self, vector: "QVector3D") -> None:
        """
        https://doc.qt.io/qt-6/qmatrix4x4.html#scale

        **void QMatrix4x4::scale(const QVector3D & vector )**

        Multiplies this matrix by another that scales coordinates by the
        components of **vector**.

        **See also** **translate** () and **rotate** ().
        """
        ...

    @typing.overload
    def scale(self, x: float, y: float) -> None:
        """
        https://doc.qt.io/qt-6/qmatrix4x4.html#scale-1

        **void QMatrix4x4::scale(float x , float y )**

        This is an overloaded function.

        Multiplies this matrix by another that scales coordinates by the
        components **x** , and **y**.

        **See also** **translate** () and **rotate** ().
        """
        ...

    @typing.overload
    def scale(self, x: float, y: float, z: float) -> None:
        """
        https://doc.qt.io/qt-6/qmatrix4x4.html#scale-2

        **void QMatrix4x4::scale(float x , float y , float z )**

        This is an overloaded function.

        Multiplies this matrix by another that scales coordinates by the
        components **x** , **y** , and **z**.

        **See also** **translate** () and **rotate** ().
        """
        ...

    @typing.overload
    def scale(self, factor: float) -> None:
        """
        https://doc.qt.io/qt-6/qmatrix4x4.html#scale-3

        **void QMatrix4x4::scale(float factor )**

        This is an overloaded function.

        Multiplies this matrix by another that scales coordinates by the given
        **factor**.

        **See also** **translate** () and **rotate** ().
        """
        ...

    def normalMatrix(self) -> QMatrix3x3:
        """
        https://doc.qt.io/qt-6/qmatrix4x4.html#normalMatrix

        **QMatrix3x3 QMatrix4x4::normalMatrix() const**

        Returns the normal matrix corresponding to this 4x4 transformation. The
        normal matrix is the transpose of the inverse of the top-left 3x3 part
        of this 4x4 matrix. If the 3x3 sub-matrix is not invertible, this
        function returns the identity.

        **See also** **inverted** ().
        """
        ...

    def transposed(self) -> "QMatrix4x4":
        """
        https://doc.qt.io/qt-6/qmatrix4x4.html#transposed

        **QMatrix4x4 QMatrix4x4::transposed() const**

        Returns this matrix, transposed about its diagonal.
        """
        ...

    def inverted(self) -> typing.Tuple["QMatrix4x4", bool]:
        """
        https://doc.qt.io/qt-6/qmatrix4x4.html#inverted

        **QMatrix4x4 QMatrix4x4::inverted(bool * invertible = nullptr) const**

        Returns the inverse of this matrix. Returns the identity if this matrix
        cannot be inverted; i.e. **determinant** () is zero. If **invertible**
        is not null, then true will be written to that location if the matrix
        can be inverted; false otherwise.

        If the matrix is recognized as the identity or an orthonormal matrix,
        then this function will quickly invert the matrix using optimized
        routines.

        **See also** **determinant** () and **normalMatrix** ().
        """
        ...

    def determinant(self) -> float:
        """
        https://doc.qt.io/qt-6/qmatrix4x4.html#determinant

        **double QMatrix4x4::determinant() const**

        Returns the determinant of this matrix.
        """
        ...

    def __repr__(self) -> str:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QVector4D(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qvector4d.html

    **Detailed Description**

    Vectors are one of the main building blocks of 4D affine representations of
    3D space. They consist of four finite floating-point coordinates,
    traditionally called x, y, z and w.

    The QVector4D class can also be used to represent vertices in 4D space. We
    therefore do not need to provide a separate vertex class.

    **See also** **QQuaternion** , **QVector2D** , and **QVector3D** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qvector4d.html#QVector4D

        **QVector4D::QVector4D()**

        Constructs a null vector, i.e. with coordinates (0, 0, 0, 0).
        """
        ...

    @typing.overload
    def __init__(self, xpos: float, ypos: float, zpos: float, wpos: float) -> None:
        """
        https://doc.qt.io/qt-6/qvector4d.html#QVector4D-2

        **QVector4D::QVector4D(float xpos , float ypos , float zpos , float wpos
        )**

        Constructs a vector with coordinates ( **xpos** , **ypos** , **zpos** ,
        **wpos** ). All parameters must be finite.
        """
        ...

    @typing.overload
    def __init__(self, point: QtCore.QPoint) -> None:
        """
        https://doc.qt.io/qt-6/qvector4d.html#QVector4D-3

        **QVector4D::QVector4D(QPoint point )**

        Constructs a vector with x and y coordinates from a 2D **point** , and z
        and w coordinates of 0.
        """
        ...

    @typing.overload
    def __init__(self, point: QtCore.QPointF) -> None:
        """
        https://doc.qt.io/qt-6/qvector4d.html#QVector4D-4

        **QVector4D::QVector4D(QPointF point )**

        Constructs a vector with x and y coordinates from a 2D **point** , and z
        and w coordinates of 0.
        """
        ...

    @typing.overload
    def __init__(self, vector: QVector2D) -> None:
        """
        https://doc.qt.io/qt-6/qvector4d.html#QVector4D-5

        **QVector4D::QVector4D(QVector2D vector )**

        Constructs a 4D vector from the specified 2D **vector**. The z and w
        coordinates are set to zero.

        **See also** **toVector2D** ().
        """
        ...

    @typing.overload
    def __init__(self, vector: QVector2D, zpos: float, wpos: float) -> None:
        """
        https://doc.qt.io/qt-6/qvector4d.html#QVector4D-6

        **QVector4D::QVector4D(QVector2D vector , float zpos , float wpos )**

        Constructs a 4D vector from the specified 2D **vector**. The z and w
        coordinates are set to **zpos** and **wpos** respectively, each of which
        must be finite.

        **See also** **toVector2D** ().
        """
        ...

    @typing.overload
    def __init__(self, vector: QVector3D) -> None:
        """
        https://doc.qt.io/qt-6/qvector4d.html#QVector4D-7

        **QVector4D::QVector4D(QVector3D vector )**

        Constructs a 4D vector from the specified 3D **vector**. The w
        coordinate is set to zero.

        **See also** **toVector3D** ().
        """
        ...

    @typing.overload
    def __init__(self, vector: QVector3D, wpos: float) -> None:
        """
        https://doc.qt.io/qt-6/qvector4d.html#QVector4D-8

        **QVector4D::QVector4D(QVector3D vector , float wpos )**

        Constructs a 4D vector from the specified 3D **vector**. The w
        coordinate is set to **wpos** , which must be finite.

        **See also** **toVector3D** ().
        """
        ...

    @typing.overload
    def __init__(self, a0: "QVector4D") -> None:
        """
        https://doc.qt.io/qt-6/qvector4d.html#QVector4D

        **QVector4D::QVector4D()**

        Constructs a null vector, i.e. with coordinates (0, 0, 0, 0).
        """
        ...

    def __neg__(self) -> "QVector4D":
        ...

    def toPointF(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qvector4d.html#toPointF

        **QPointF QVector4D::toPointF() const**

        Returns the **QPointF**  form of this 4D vector. The z and w coordinates
        are dropped.

        **See also** **toPoint** () and **toVector2D** ().
        """
        ...

    def toPoint(self) -> QtCore.QPoint:
        """
        https://doc.qt.io/qt-6/qvector4d.html#toPoint

        **QPoint QVector4D::toPoint() const**

        Returns the **QPoint**  form of this 4D vector. The z and w coordinates
        are dropped. The x and y coordinates are rounded to nearest integers.

        **See also** **toPointF** () and **toVector2D** ().
        """
        ...

    def toVector3DAffine(self) -> QVector3D:
        """
        https://doc.qt.io/qt-6/qvector4d.html#toVector3DAffine

        **QVector3D QVector4D::toVector3DAffine() const**

        Returns the 3D vector form of this 4D vector, dividing the x, y, and z
        coordinates by the w coordinate. Returns a null vector if w is zero.

        **See also** **toVector3D** (), **toVector2DAffine** (), and **toPoint**
        ().
        """
        ...

    def toVector3D(self) -> QVector3D:
        """
        https://doc.qt.io/qt-6/qvector4d.html#toVector3D

        **QVector3D QVector4D::toVector3D() const**

        Returns the 3D vector form of this 4D vector, dropping the w coordinate.

        **See also** **toVector3DAffine** (), **toVector2D** (), and **toPoint**
        ().
        """
        ...

    def toVector2DAffine(self) -> QVector2D:
        """
        https://doc.qt.io/qt-6/qvector4d.html#toVector2DAffine

        **QVector2D QVector4D::toVector2DAffine() const**

        Returns the 2D vector form of this 4D vector, dividing the x and y
        coordinates by the w coordinate and dropping the z coordinate. Returns a
        null vector if w is zero.

        **See also** **toVector2D** (), **toVector3DAffine** (), and **toPoint**
        ().
        """
        ...

    def toVector2D(self) -> QVector2D:
        """
        https://doc.qt.io/qt-6/qvector4d.html#toVector2D

        **QVector2D QVector4D::toVector2D() const**

        Returns the 2D vector form of this 4D vector, dropping the z and w
        coordinates.

        **See also** **toVector2DAffine** (), **toVector3D** (), and **toPoint**
        ().
        """
        ...

    @staticmethod
    def dotProduct(v1: "QVector4D", v2: "QVector4D") -> float:
        """
        https://doc.qt.io/qt-6/qvector4d.html#dotProduct

        **[static] float QVector4D::dotProduct(QVector4D v1 , QVector4D v2 )**

        Returns the dot product of **v1** and **v2**.
        """
        ...

    def normalize(self) -> None:
        """
        https://doc.qt.io/qt-6/qvector4d.html#normalize

        **void QVector4D::normalize()**

        Normalizes the currect vector in place. Nothing happens if this vector
        is a null vector or the length of the vector is very close to 1.

        **See also** **length** () and **normalized** ().
        """
        ...

    def normalized(self) -> "QVector4D":
        """
        https://doc.qt.io/qt-6/qvector4d.html#normalized

        **QVector4D QVector4D::normalized() const**

        Returns the normalized unit vector form of this vector.

        If this vector is null, then a null vector is returned. If the length of
        the vector is very close to 1, then the vector will be returned as-is.
        Otherwise the normalized form of the vector of length 1 will be
        returned.

        **See also** **length** () and **normalize** ().
        """
        ...

    def lengthSquared(self) -> float:
        """
        https://doc.qt.io/qt-6/qvector4d.html#lengthSquared

        **float QVector4D::lengthSquared() const**

        Returns the squared length of the vector from the origin. This is
        equivalent to the dot product of the vector with itself.

        **See also** **length** () and **dotProduct** ().
        """
        ...

    def length(self) -> float:
        """
        https://doc.qt.io/qt-6/qvector4d.html#length

        **float QVector4D::length() const**

        Returns the length of the vector from the origin.

        **See also** **lengthSquared** () and **normalized** ().
        """
        ...

    def __getitem__(self, i: int) -> float:
        ...

    def setW(self, w: float) -> None:
        """
        https://doc.qt.io/qt-6/qvector4d.html#setW

        **void QVector4D::setW(float w )**

        Sets the w coordinate of this point to the given finite **w**
        coordinate.

        **See also** **w** (), **setX** (), **setY** (), and **setZ** ().
        """
        ...

    def setZ(self, z: float) -> None:
        """
        https://doc.qt.io/qt-6/qvector4d.html#setZ

        **void QVector4D::setZ(float z )**

        Sets the z coordinate of this point to the given finite **z**
        coordinate.

        **See also** **z** (), **setX** (), **setY** (), and **setW** ().
        """
        ...

    def setY(self, y: float) -> None:
        """
        https://doc.qt.io/qt-6/qvector4d.html#setY

        **void QVector4D::setY(float y )**

        Sets the y coordinate of this point to the given finite **y**
        coordinate.

        **See also** **y** (), **setX** (), **setZ** (), and **setW** ().
        """
        ...

    def setX(self, x: float) -> None:
        """
        https://doc.qt.io/qt-6/qvector4d.html#setX

        **void QVector4D::setX(float x )**

        Sets the x coordinate of this point to the given finite **x**
        coordinate.

        **See also** **x** (), **setY** (), **setZ** (), and **setW** ().
        """
        ...

    def w(self) -> float:
        """
        https://doc.qt.io/qt-6/qvector4d.html#w

        **float QVector4D::w() const**

        Returns the w coordinate of this point.

        **See also** **setW** (), **x** (), **y** (), and **z** ().
        """
        ...

    def z(self) -> float:
        """
        https://doc.qt.io/qt-6/qvector4d.html#z

        **float QVector4D::z() const**

        Returns the z coordinate of this point.

        **See also** **setZ** (), **x** (), **y** (), and **w** ().
        """
        ...

    def y(self) -> float:
        """
        https://doc.qt.io/qt-6/qvector4d.html#y

        **float QVector4D::y() const**

        Returns the y coordinate of this point.

        **See also** **setY** (), **x** (), **z** (), and **w** ().
        """
        ...

    def x(self) -> float:
        """
        https://doc.qt.io/qt-6/qvector4d.html#x

        **float QVector4D::x() const**

        Returns the x coordinate of this point.

        **See also** **setX** (), **y** (), **z** (), and **w** ().
        """
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qvector4d.html#isNull

        **bool QVector4D::isNull() const**

        Returns `true` if the x, y, z, and w coordinates are set to 0.0,
        otherwise returns `false`.
        """
        ...

    def __repr__(self) -> str:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtPositioning import *


class QGeoCircle(QGeoShape):
    """
    https://doc.qt.io/qt-6/qgeocircle.html

    **Detailed Description**

    The circle is defined in terms of a **QGeoCoordinate**  which specifies the
    center of the circle and a qreal which specifies the radius of the circle in
    meters.

    The circle is considered invalid if the center coordinate is invalid or if
    the radius is less than zero.

    This class is a **Q_GADGET**  since Qt 5.5. It can be **directly used from
    C++ and QML** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qgeocircle.html#QGeoCircle

        **QGeoCircle::QGeoCircle()**

        Constructs a new, invalid geo circle.
        """
        ...

    @typing.overload
    def __init__(self, center: "QGeoCoordinate", radius: float = ...) -> None:
        """
        https://doc.qt.io/qt-6/qgeocircle.html#QGeoCircle-1

        **QGeoCircle::QGeoCircle(const QGeoCoordinate & center , qreal radius =
        -1.0)**

        Constructs a new geo circle centered at **center** and with a radius of
        **radius** meters.
        """
        ...

    @typing.overload
    def __init__(self, other: "QGeoCircle") -> None:
        """
        https://doc.qt.io/qt-6/qgeocircle.html#QGeoCircle-2

        **QGeoCircle::QGeoCircle(const QGeoCircle & other )**

        Constructs a new geo circle from the contents of **other**.
        """
        ...

    @typing.overload
    def __init__(self, other: QGeoShape) -> None:
        """
        https://doc.qt.io/qt-6/qgeocircle.html#QGeoCircle-3

        **QGeoCircle::QGeoCircle(const QGeoShape & other )**

        Constructs a new geo circle from the contents of **other**.
        """
        ...

    def extendCircle(self, coordinate: "QGeoCoordinate") -> None:
        """
        https://doc.qt.io/qt-6/qgeocircle.html#extendCircle

        **[invokable, since 5.9] void QGeoCircle::extendCircle(const
        QGeoCoordinate & coordinate )**

        Extends the geo circle to also cover the coordinate **coordinate**

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .

        This function was introduced in Qt 5.9.
        """
        ...

    def toString(self) -> str:
        """
        https://doc.qt.io/qt-6/qgeocircle.html#toString

        **[invokable, since 5.5] QString QGeoCircle::toString() const**

        Returns the geo circle properties as a string.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .

        This function was introduced in Qt 5.5.
        """
        ...

    def translated(
        self, degreesLatitude: float, degreesLongitude: float
    ) -> "QGeoCircle":
        """
        https://doc.qt.io/qt-6/qgeocircle.html#translated

        **[invokable] QGeoCircle QGeoCircle::translated(double degreesLatitude ,
        double degreesLongitude ) const**

        Returns a copy of this geo circle translated by **degreesLatitude**
        northwards and **degreesLongitude** eastwards.

        Negative values of **degreesLatitude** and **degreesLongitude**
        correspond to southward and westward translation respectively.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .

        **See also** **translate** ().
        """
        ...

    def translate(self, degreesLatitude: float, degreesLongitude: float) -> None:
        """
        https://doc.qt.io/qt-6/qgeocircle.html#translate

        **[invokable] void QGeoCircle::translate(double degreesLatitude , double
        degreesLongitude )**

        Translates this geo circle by **degreesLatitude** northwards and
        **degreesLongitude** eastwards.

        Negative values of **degreesLatitude** and **degreesLongitude**
        correspond to southward and westward translation respectively.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    def radius(self) -> float:
        """
        https://doc.qt.io/qt-6/qgeocircle.html#radius

        **qreal QGeoCircle::radius() const**

        Returns the radius in meters of this geo circle.

        **Note:** Getter function for property **radius** .

        **See also** **setRadius** ().
        """
        ...

    def setRadius(self, radius: float) -> None:
        """
        https://doc.qt.io/qt-6/qgeocircle.html#setRadius

        **void QGeoCircle::setRadius(qreal radius )**

        Sets the radius in meters of this geo circle to **radius**.

        **Note:** Setter function for property **radius** .

        **See also** **radius** ().
        """
        ...

    def center(self) -> "QGeoCoordinate":
        """
        https://doc.qt.io/qt-6/qgeocircle.html#center

        **QGeoCoordinate QGeoCircle::center() const**

        Returns the center coordinate of this geo circle. Equivalent to
        **QGeoShape::center** ().

        **Note:** Getter function for property **center** .

        **See also** **setCenter** ().
        """
        ...

    def setCenter(self, center: "QGeoCoordinate") -> None:
        """
        https://doc.qt.io/qt-6/qgeocircle.html#setCenter

        **void QGeoCircle::setCenter(const QGeoCoordinate & center )**

        Sets the center coordinate of this geo circle to **center**.

        **Note:** Setter function for property **center** .

        **See also** **center** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from ._functions import PYQT_SIGNAL as PYQT_SIGNAL
from ._functions import PYQT_SLOT as PYQT_SLOT
from ._functions import PYQT_OPENGL_ARRAY as PYQT_OPENGL_ARRAY
from ._functions import PYQT_OPENGL_BOUND_ARRAY as PYQT_OPENGL_BOUND_ARRAY
from ._functions import PYQT_SHADER_ATTRIBUTE_ARRAY as PYQT_SHADER_ATTRIBUTE_ARRAY
from ._functions import (
    PYQT_SHADER_UNIFORM_VALUE_ARRAY as PYQT_SHADER_UNIFORM_VALUE_ARRAY,
)
from ._QOpenGLBuffer import QOpenGLBuffer as QOpenGLBuffer
from ._QOpenGLDebugMessage import QOpenGLDebugMessage as QOpenGLDebugMessage
from ._QOpenGLDebugLogger import QOpenGLDebugLogger as QOpenGLDebugLogger
from ._QOpenGLFramebufferObject import (
    QOpenGLFramebufferObject as QOpenGLFramebufferObject,
)
from ._QOpenGLFramebufferObjectFormat import (
    QOpenGLFramebufferObjectFormat as QOpenGLFramebufferObjectFormat,
)
from ._QOpenGLPaintDevice import QOpenGLPaintDevice as QOpenGLPaintDevice
from ._QOpenGLPixelTransferOptions import (
    QOpenGLPixelTransferOptions as QOpenGLPixelTransferOptions,
)
from ._QOpenGLShader import QOpenGLShader as QOpenGLShader
from ._QOpenGLShaderProgram import QOpenGLShaderProgram as QOpenGLShaderProgram
from ._QOpenGLTexture import QOpenGLTexture as QOpenGLTexture
from ._QOpenGLTextureBlitter import QOpenGLTextureBlitter as QOpenGLTextureBlitter
from ._QOpenGLTimerQuery import QOpenGLTimerQuery as QOpenGLTimerQuery
from ._QOpenGLTimeMonitor import QOpenGLTimeMonitor as QOpenGLTimeMonitor
from ._QAbstractOpenGLFunctions import (
    QAbstractOpenGLFunctions as QAbstractOpenGLFunctions,
)
from ._QOpenGLVersionFunctionsFactory import (
    QOpenGLVersionFunctionsFactory as QOpenGLVersionFunctionsFactory,
)
from ._QOpenGLVertexArrayObject import (
    QOpenGLVertexArrayObject as QOpenGLVertexArrayObject,
)
from ._QOpenGLWindow import QOpenGLWindow as QOpenGLWindow
from ._QOpenGLFunctions_2_0 import QOpenGLFunctions_2_0 as QOpenGLFunctions_2_0
from ._QOpenGLFunctions_2_1 import QOpenGLFunctions_2_1 as QOpenGLFunctions_2_1
from ._QOpenGLFunctions_4_1_Core import (
    QOpenGLFunctions_4_1_Core as QOpenGLFunctions_4_1_Core,
)
from ._QOpenGLVersionProfile import QOpenGLVersionProfile as QOpenGLVersionProfile



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtCore


class QWhatsThisClickedEvent(QtCore.QEvent):
    """
    https://doc.qt.io/qt-6/qwhatsthisclickedevent.html

    **Detailed Description**

    **See also** **QWhatsThis** , **QHelpEvent** , and **QStatusTipEvent** .
    """

    def __init__(self, href: str) -> None:
        """
        https://doc.qt.io/qt-6/qwhatsthisclickedevent.html#QWhatsThisClickedEven
        t-2

        **QWhatsThisClickedEvent::QWhatsThisClickedEvent(const QString & href
        )**

        Constructs an event containing a URL specified by **href** when a link
        is clicked in a "What's This?" message.

        **See also** **href** ().
        """
        ...

    def clone(self) -> "QWhatsThisClickedEvent":
        ...

    def href(self) -> str:
        """
        https://doc.qt.io/qt-6/qwhatsthisclickedevent.html#href

        **QString QWhatsThisClickedEvent::href() const**

        Returns the URL that was clicked by the user in the "What's This?" text.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
from PyQt6 import QtCore
from PyQt6.QtTest import *
import enum


class QAbstractItemModelTester(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qabstractitemmodeltester.html

    **Detailed Description**

    The QAbstractItemModelTester class is a utility class to test item models.

    When implementing an item model (that is, a concrete **QAbstractItemModel**
    subclass) one must abide to a very strict set of rules that ensure
    consistency for users of the model (views, proxy models, and so on).

    For instance, for a given index, a model's reimplementation of
    **hasChildren** () must be consistent with the values returned by
    **rowCount** () and **columnCount** ().

    QAbstractItemModelTester helps catching the most common errors in custom
    item model classes. By performing a series of tests, it will try to check
    that the model status is consistent at all times. The tests will be repeated
    automatically every time the model is modified.

    QAbstractItemModelTester employs non-destructive tests, which typically
    consist in reading data and metadata out of a given item model.
    QAbstractItemModelTester will also attempt illegal modifications of the
    model. In models which are properly implemented, such attempts should be
    rejected, and no data should be changed as a consequence.

    **Usage**

    Using QAbstractItemModelTester is straightforward. In a **test case**  it is
    sufficient to create an instance, passing the model that needs to be tested
    to the constructor:

    MyModel *modelToBeTested = ...;
        auto tester = new
    **QAbstractItemModelTester** (modelToBeTested);

    QAbstractItemModelTester will report testing failures through the Qt Test
    logging mechanisms.

    It is also possible to use QAbstractItemModelTester outside of a test case.
    For instance, it may be useful to test an item model used by an application
    without the need of building an explicit unit test for such a model (which
    might be challenging). In order to use QAbstractItemModelTester outside of a
    test case, pass one of the `QAbstractItemModelTester::FailureReportingMode`
    enumerators to its constructor, therefore specifying how failures should be
    logged.

    QAbstractItemModelTester may also report additional debugging information as
    logging messages under the `qt.modeltest` logging category. Such debug
    logging is disabled by default; refer to the **QLoggingCategory**
    documentation to learn how to enable it.

    **Note:** While QAbstractItemModelTester is a valid help for development and
    testing of custom item models, it does not (and cannot) catch all possible
    problems in **QAbstractItemModel**  subclasses. Notably, it will never
    perform meaningful destructive testing of a model, which must be therefore
    tested separately.

    **See also** **Model/View Programming**  and **QAbstractItemModel** .
    """

    class FailureReportingMode(enum.Enum):
        QtTest: QAbstractItemModelTester = ...
        Warning: QAbstractItemModelTester = ...
        Fatal: QAbstractItemModelTester = ...

    @typing.overload
    def __init__(
        self,
        model: QtCore.QAbstractItemModel,
        parent: typing.Optional[QtCore.QObject] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemmodeltester.html#QAbstractItemModelT
        ester

        **QAbstractItemModelTester::QAbstractItemModelTester(QAbstractItemModel
        * model , QObject * parent = nullptr)**

        Creates a model tester instance, with the given **parent** , that will
        test the model **model**.
        """
        ...

    @typing.overload
    def __init__(
        self,
        model: QtCore.QAbstractItemModel,
        mode: "QAbstractItemModelTester.FailureReportingMode",
        parent: typing.Optional[QtCore.QObject] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemmodeltester.html#QAbstractItemModelT
        ester-1

        **QAbstractItemModelTester::QAbstractItemModelTester(QAbstractItemModel
        * model , QAbstractItemModelTester::FailureReportingMode mode , QObject
        * parent = nullptr)**

        Creates a model tester instance, with the given **parent** , that will
        test the model **model** , using the specified **mode** to report test
        failures.

        **See also** **QAbstractItemModelTester::FailureReportingMode** .
        """
        ...

    def failureReportingMode(self) -> "QAbstractItemModelTester.FailureReportingMode":
        """
        https://doc.qt.io/qt-6/qabstractitemmodeltester.html#failureReportingMod
        e

        **QAbstractItemModelTester::FailureReportingMode
        QAbstractItemModelTester::failureReportingMode() const**

        Returns the mode that this instancing is using to report test failures.

        **See also** **QAbstractItemModelTester::FailureReportingMode** .
        """
        ...

    def model(self) -> QtCore.QAbstractItemModel:
        """
        https://doc.qt.io/qt-6/qabstractitemmodeltester.html#model

        **QAbstractItemModel *QAbstractItemModelTester::model() const**

        Returns the model that this instance is testing.
        """
        ...
